@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains debugging functions. */
@@ -678,12 +678,12 @@ int last;
 uschar *c = "";
 debug_printf("%s = ", s);
 
-for (i = 0; i <= max_stave; i++)
+for (i = 0; i <= MAX_STAVE; i++)
   {
   if (mac_teststave(map, i))
     {
     int s = i;
-    while (++i <= max_stave && mac_teststave(map, i));
+    while (++i <= MAX_STAVE && mac_teststave(map, i));
     if (s == i-1) debug_printf("%s%d", c, s);
       else debug_printf("%s%d-%d", c, s, i-1);
     last = i-1;
@@ -859,17 +859,15 @@ debug_printf("fontsize_barno = %f\n", m->fontsizes->fontsize_barno);
 debug_printf("fontsize_clefs = %f\n", m->fontsizes->fontsize_clefs);
 debug_printf("fontsize_cue = %f\n", m->fontsizes->fontsize_cue);
 debug_printf("fontsize_cuegrace = %f\n", m->fontsizes->fontsize_cuegrace);
-debug_printf("fontsize_fbass = %f\n", m->fontsizes->fontsize_fbass);
 debug_printf("fontsize_grace = %f\n", m->fontsizes->fontsize_grace);
 debug_printf("fontsize_music = %f\n", m->fontsizes->fontsize_music);
-debug_printf("fontsize_olay = %f\n", m->fontsizes->fontsize_olay);
 debug_printf("fontsize_rehearse = %f\n", m->fontsizes->fontsize_rehearse);
 debug_printf("fontsize_repno = %f\n", m->fontsizes->fontsize_repno);
 debug_printf("fontsize_restct = %f\n", m->fontsizes->fontsize_restct);
 
 comma = "";
 debug_printf("fontsize_text = ");
-for (i = 0; i < MaxTextFont; i++)
+for (i = 0; i < MaxFontSizes; i++)
   {
   debug_printf("%s%f", comma, m->fontsizes->fontsize_text[i]);
   comma = ", ";
@@ -878,8 +876,11 @@ debug_printf("\n");
 
 debug_printf("fontsize_trill = %f\n", m->fontsizes->fontsize_trill);
 debug_printf("fontsize_triplet = %f\n", m->fontsizes->fontsize_triplet);
-debug_printf("fontsize_tsfont = %f\n", m->fontsizes->fontsize_tsfont);
-debug_printf("fontsize_ulay = %f\n", m->fontsizes->fontsize_ulay);
+
+debug_printf("fontsize_tsfont = %f\n", (m->fontsizes->fontsize_text)[ff_offset_tsfont]);
+debug_printf("fontsize_ulay = %f\n", (m->fontsizes->fontsize_text)[ff_offset_ulay]);
+debug_printf("fontsize_olay = %f\n", (m->fontsizes->fontsize_text)[ff_offset_olay]);
+debug_printf("fontsize_fbass = %f\n", (m->fontsizes->fontsize_text)[ff_offset_fbass]);
 
 debug_printf("fullbarend = %B\n", m->fullbarend);
 debug_printf("gracespacing = %f %f\n", m->gracespacing[0],
@@ -965,7 +966,7 @@ for (i = 0; i <= m->laststave; i++)
   }
 
 debug_printf("stavesizes = ");
-for (i = 1; i <= max_stave; i++)
+for (i = 1; i <= MAX_STAVE; i++)
   {
   int size = (m->stavesizes)[i];
   if (size != 1000) debug_printf("%d/%f ", i, size);
