@@ -2,11 +2,11 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2013 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
 /* Re-coded for Unicode support: August 2005 */
-/* This file last modified: December 2013 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains code for handling text fonts */
@@ -802,7 +802,7 @@ static void
 font_addbasefont(uschar *psfont)
 {
 fontstr *fs = &(font_List[font_basecount]);
-if (font_basecount >= max_fonts) { error_moan(26, max_fonts); return; }
+if (font_basecount >= MAX_FONTS) { error_moan(26, MAX_FONTS); return; }
 fs->psname = malloc(Ustrlen(psfont)+1);
 Ustrcpy(fs->psname, psfont);
 fs->widths = NULL;
@@ -945,7 +945,7 @@ while (*s != 0)
       lastc >= 0 && lastc <= 0xffff && c <= 0xffff)
     {
     int top, bot, mid;
-    unsigned int pair = (lastc << 16) | c;
+    unsigned int pair = (unsigned int)((unsigned int)lastc << 16) | c;
 
     bot = 0;
     top = kerncount;
