@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2013 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: March 2013 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains all the global data */
@@ -108,8 +108,8 @@ BOOL main_kerning;
 int  main_lastmovement = 0;
 int  main_lastpage;
 int  main_magnification;
-int  main_max_bars = def_max_bars;
-int  main_max_movements = def_max_movements;
+int  main_max_bars = DEF_MAX_BARS;
+int  main_max_movements = DEF_MAX_MOVEMENTS;
 int  main_maxvertjustify;
 uschar *main_musicchoice = US"PMW-Music";
 int  main_notenum;
@@ -127,7 +127,7 @@ int  main_sheetheight;
 int  main_sheetwidth;
 BOOL main_shownlogo = FALSE;
 int  main_stavemagn;
-int  main_staves[stave_bitvec_size] = { -1, -1 };
+int  main_staves[STAVE_BITVEC_SIZE] = { -1, -1 };
 int  main_storetotal = 0;
 int  main_storestaves = 0;
 int  main_stretchrespacethresh = 1075;
@@ -168,6 +168,7 @@ BOOL n_invertright;
 int  n_lastacc;
 b_notestr *n_lastnote;
 int  n_length;
+int  n_longrestmid;
 int  n_masq;
 int  n_maxaccleft;
 int  n_maxpitch;
@@ -222,7 +223,7 @@ BOOL out_lastbarwide;
 BOOL out_lastnotebeamed;
 int  out_lastnotex;
 int  out_laststave;
-uschar out_laststemup[max_stave+1];
+uschar out_laststemup[MAX_STAVE+1];
 BOOL out_lineendflag;
 BOOL out_makedraw = FALSE;
 int  out_manyrest;
@@ -259,8 +260,8 @@ int  out_stavetop;
 sysblock *out_sysblock;
 int  out_textnextabove;
 int  out_textnextbelow;
-b_textstr *out_textqueue[20];
-b_textXstr *out_textXqueue[20];
+b_textstr *out_textqueue[TEXT_QUEUE_SIZE];
+b_textXstr *out_textXqueue[TEXT_QUEUE_SIZE];
 int  out_textqueueptr;
 b_textXstr *out_textX;
 int  out_timecount;
@@ -324,7 +325,7 @@ workposstr *page_posptr;
 workposstr *page_postable;
 BOOL page_savehadmovt;
 int  page_sgnext;
-unsigned int page_showtimes[stave_bitvec_size];
+unsigned int page_showtimes[STAVE_BITVEC_SIZE];
 int *page_ssnext;
 int *page_ssehere;
 int *page_ssenext;
@@ -332,7 +333,7 @@ BOOL page_startchangetime;
 startlinestr *page_startline;
 BOOL page_startlinebar;
 int  page_stave;
-unsigned int  page_stavemap[stave_bitvec_size];
+unsigned int  page_stavemap[STAVE_BITVEC_SIZE];
 uschar *page_sysclef;
 sysblock *page_sysblock;
 sysblock **page_sysprevptr;
@@ -448,6 +449,8 @@ int  stave_maxaway;
 int  stave_maxpitch;
 int  stave_minpitch;
 BOOL stave_notes;
+int  stave_noteden;
+int  stave_notenum;
 int  stave_octave;
 int  stave_olfont;
 int  stave_olsize;
@@ -487,9 +490,10 @@ int  stave_totalnocount;
 int  stave_transpose;
 int  stave_transpose_letter;
 BOOL stave_transposedaccforce;
+BOOL stave_tripletize;
 int  stave_ulfont;
 int  stave_ulsize;
-BOOL stave_use_draw = FALSE;
+int  stave_use_draw = 0;
 BOOL stave_use_widechars = TRUE;
 
 int  string_font;
