@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains initializing and other housekeeping functions. */
@@ -87,29 +87,27 @@ fclose(f);
 *************************************************/
 
 /* This is called before argument decoding is done. It is passed the argument 
-list, and it has the opportunity of modifying that list. Unless configured not 
-to include this code, we search for a .pmwrc file and stuff it on the front of
-the arguments. 
+list, and it has the opportunity of modifying that list as it copies it into a 
+new vector. Unless configured not to include this code, we search for a .pmwrc
+file and stuff it on the front of the arguments.
 
 Arguments:
   argc          argc from main()
   argv          argv from main()
-  newargvptr    where to return the possibly modified argv
+  nargv         where to return the possibly modified argv
   arg_pattern   the argument decoding pattern, to check for validity
   
 Returns:        new argc value  
 */
 
 int 
-init_command(int argc, char **argv, char ***newargvptr, const char *arg_pattern)
+init_command(int argc, char **argv, char **nargv, const char *arg_pattern)
 {
-char **nargv;
 int ap = 0;
 int nargc = 0;
 
 (void)argc;   /* Unused; avoid compiler warning */
 
-*newargvptr = nargv = malloc(100 * sizeof(char *));
 nargv[nargc++] = argv[ap++];    /* Program name */
 
 /* This will need to be cut out on non-Unix-like systems */
