@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains initializing code, including the main program, which is
@@ -48,7 +48,7 @@ static const char *arg_pattern =
   "c/k/n,"
   "debug/s,"
   "dbl=drawbarlines/s," 
-  "dsl=drawstavelines/s," 
+  "dsl=drawstavelines=drawstafflines/n=3," 
   "dsb/k,"
   "dtp/k/n,"
   "duplex/s,"
@@ -65,7 +65,7 @@ static const char *arg_pattern =
   "midi/k,"
   "mb=midibars/k,"
   "mm=midimovement/k/n,"
-  "nr=norepeats/s,"
+  "nr=norepeats=norepeat/s,"
   "nw=nowidechars/s,"
   "o/k,"
   "p/k,"
@@ -133,6 +133,9 @@ static int dsb_bar = -1;
 static int dsb_movement = -1;
 static int dsb_stave = -1;
 
+/* Vector for modified command line options */
+
+static char **newargv;
 
 
 /*************************************************
@@ -152,9 +155,9 @@ printf("-c <number>           set number of copies\n");
 printf("-debug                write debugging info to stderr\n");
 printf("-dbl                  synonym for -drawbarlines\n");
 printf("-drawbarlines         don't use characters for bar lines\n");
-printf("-drawstavelines       don't use characters for stave lines\n");
+printf("-drawstavelines [<n>] don't use characters for stave lines\n");
 printf("-dsb <m>,<s>,<b>      write debugging bar data (movement, stave, bar) \n");
-printf("-dsl                  synonym for -drawstavelines\n");
+printf("-dsl [<n>]            synonym for -drawstavelines\n");
 printf("-dtp <bar>            write debugging position data (-1 for all bars)\n");
 printf("-duplex               set duplex printing in the PostScript\n");
 printf("-eps                  output encapsulated PostScript\n");
@@ -250,10 +253,10 @@ display_info(void)
 pagestr *p = main_pageanchor;
 int movt;
 int laststave = -1;
-int toppitch[max_stave+1];
-int botpitch[max_stave+1];
-int totalpitch[max_stave+1];
-int notecount[max_stave+1];
+int toppitch[MAX_STAVE+1];
+int botpitch[MAX_STAVE+1];
+int totalpitch[MAX_STAVE+1];
+int notecount[MAX_STAVE+1];
 
 info_printf("Data store used = ");
 if (main_storetotal < 10000) info_printf("%d", main_storetotal);
@@ -403,7 +406,7 @@ while (isdigit(*sss))
     sss++;
     t = strtol(sss, &sss, 0);
     }
-  if (t < s || t > max_stave) return;   /* Not reached end will give error */
+  if (t < s || t > MAX_STAVE) return;   /* Not reached end will give error */
   for (i = s; i <= t; i++) mac_setstave(map, i);
   while (*sss == ',' || *sss == ' ') sss++;
   }
@@ -546,9 +549,14 @@ if (results[arg_midimovement].presence != arg_present_not)
 
 if (results[arg_norepeats].number != 0) play_repeats = FALSE;
 if (results[arg_nowidechars].number != 0) stave_use_widechars = FALSE;
-if (results[arg_drawstavelines].number != 0) stave_use_draw = TRUE;
 if (results[arg_drawbarlines].number != 0) bar_use_draw = TRUE;
 
+/* Draw stave lines instead of using font characters: the thickness can 
+optionally be altered. */
+
+if (results[arg_drawstavelines].presence != arg_present_not) 
+  stave_use_draw = results[arg_drawstavelines].number;
+
 /* Deal with stave selection */
 
 if (results[arg_s].text != NULL)
@@ -664,6 +672,19 @@ if (results[arg_printside].presence != arg_present_not)
 
 
 
+/*************************************************
+*              Exit function                     *
+*************************************************/
+
+/* Used to free various chunks of memory. */
+
+static void
+clean_up(void)
+{
+free(newargv);
+}
+
+
 /*************************************************
 *                Entry Point                     *
 *************************************************/
@@ -672,7 +693,6 @@ int
 main(int argc, char **argv)
 {
 int newargc;
-char **newargv;
 uschar to_buffer[256];
 verify = FALSE;
 ps_file = stdout;
@@ -685,17 +705,19 @@ ps_header = US PSHEADER;
 midi_voices = US MIDIVOICES;
 midi_perc = US MIDIPERC;
 
+(void)atexit(clean_up);
 version_init();
 
-font_List = malloc(max_fonts * sizeof(fontstr));
+font_List = malloc(MAX_FONTS * sizeof(fontstr));
 font_table = malloc(font_tablen * sizeof(int));
 
-beam_stemadjusts = malloc(max_beamsize);
+beam_stemadjusts = malloc(MAX_BEAMSIZE);
 movement = malloc((main_max_movements+1) * sizeof(movtstr *));
 
 /* Decode the (possibly modified) command line. */
 
-newargc = init_command(argc, argv, &newargv, arg_pattern);
+newargv = malloc(100 * sizeof(char *));
+newargc = init_command(argc, argv, newargv, arg_pattern);
 decode_command(newargc, newargv);
 if (verify)
   {
