@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains code for writing a MIDI file */
@@ -20,6 +20,8 @@ typedef struct midi_event {
   uschar data[8];
 } midi_event;
 
+enum { HR_NONE, HR_REPEATED, HR_PLAYON };
+
 
 /*************************************************
 *             Local variables                    *
@@ -33,27 +35,30 @@ static int      next_event_seq;
 static int      last_written_time;
 static int      running_status;
 
-static uschar   midi_channel[max_stave+1];
-static uschar   midi_channel_volume[midi_maxchannel];
+static uschar   midi_channel[MAX_STAVE+1];
+static uschar   midi_channel_volume[MIDI_MAXCHANNEL];
 static FILE    *midi_file;
-static uschar   midi_note[max_stave+1];
+static uschar   midi_note[MAX_STAVE+1];
 
 
 static int      play_bar;
+static int      play_bar_moff;
 static movtstr *play_movt;
 static int      play_nextbar;
+static int      play_nextbar_moff;
 static BOOL     play_onebar_only = FALSE;
-static int      play_staves[stave_bitvec_size] = { -1, -1 };
+static int      play_staves[STAVE_BITVEC_SIZE] = { -1, -1 };
 static int      play_tempo;
 static int      play_volume = 127;
 
 static int      repeat_bar;
+static int      repeat_bar_moff;
 static int      repeat_count;
 static int      repeat_endbar;
 
-static uschar   stavetie[max_stave+1];
-static signed char midi_transpose[max_stave+1];
-static uschar   stave_volume[max_stave+1];
+static uschar   stavetie[MAX_STAVE+1];
+static signed char midi_transpose[MAX_STAVE+1];
+static uschar   stave_volume[MAX_STAVE+1];
 
 
 /*************************************************
@@ -333,8 +338,9 @@ Returns:    nothing
 static void
 writebar(BOOL is_lastbar)
 {
-BOOL hadrepeat = FALSE;
 BOOL oknbar = TRUE;
+int hadrepeat = HR_NONE;
+int maxmoff = 0;
 int stave;
 int *ptc = play_movt->play_tempo_changes;
 int this_barlength = find_barlength();
@@ -371,6 +377,8 @@ keep track between bars. */
 
 for (stave = 1; stave <= play_movt->laststave; stave++)
   {
+  int moff = 0;
+
   if (mac_teststave(play_staves, stave))
     {
     bstr *p = ((play_movt->stavetable)[stave])->barindex[play_bar];
@@ -379,7 +387,6 @@ for (stave = 1; stave <= play_movt->laststave; stave++)
       {
       int midi_stave_status, midi_stave_pitch, midi_stave_velocity;
       int playtranspose = midi_transpose[stave];
-      int moff = 0;
       int adjustlength = 0;
       int type = p->type;
       int tremolo = -1;
@@ -406,22 +413,47 @@ for (stave = 1; stave <= play_movt->laststave; stave++)
           moff = 0;
           break;
 
+          /* If a previous stave saw a repeat, hadrepeat is set to indicate
+          what has been done. */
+
           case b_rrepeat:
-          if (play_repeats && moff == this_barlength && !play_onebar_only && !hadrepeat)
+          if (play_repeats)
             {
-            if (repeat_count == 1)
+            if (!play_onebar_only)
               {
-              play_nextbar = repeat_bar;
-              repeat_endbar = play_bar;
-              repeat_count++;
+              switch (hadrepeat)
+                {
+                case HR_PLAYON:
+                break;
+                
+                case HR_REPEATED:
+                goto NEXT_STAVE;
+                
+                default:
+                case HR_NONE:      
+                if (repeat_count == 1)
+                  {
+                  hadrepeat = HR_REPEATED;
+                  play_nextbar = repeat_bar;
+                  play_nextbar_moff = repeat_bar_moff;
+                  repeat_endbar = play_bar;
+                  repeat_count++;
+                  goto NEXT_STAVE;   /* Skip rest of bar */
+                  } 
+                else 
+                  {
+                  hadrepeat = HR_PLAYON; 
+                  if (play_bar == repeat_endbar) repeat_count = 1;
+                  }
+                break;   
+                }    
               }
-            else if (play_bar == repeat_endbar) repeat_count = 1;
-            hadrepeat = TRUE;
             }
           break;
 
           case b_lrepeat:
-          if (moff == 0) repeat_bar = play_bar;
+          repeat_bar = play_bar;
+          repeat_bar_moff = moff;
           break;
 
           case b_nbar:
@@ -434,8 +466,11 @@ for (stave = 1; stave <= play_movt->laststave; stave++)
               if (second > 0)
                 {
                 play_bar = second;
+                play_bar_moff = 0;
                 play_nextbar = play_bar + 1;
+                play_nextbar_moff = 0;
                 repeat_bar = play_bar;
+                repeat_bar_moff = 0;
                 repeat_count = 1;
                 writebar(is_lastbar);
                 }
@@ -536,7 +571,7 @@ for (stave = 1; stave <= play_movt->laststave; stave++)
             /* nf_noplay is set when a note has already been played, because of
             a previous tie, which might have been in a previous bar. */
 
-            if ((noteson || midi_for_notes_off) &&
+            if ((noteson || midi_for_notes_off) && moff >= play_bar_moff &&
                 note->spitch != 0 && (note->flags & nf_noplay) == 0)
               {
               /* Get a list of pitches in a chord, and leave the general
@@ -553,7 +588,7 @@ for (stave = 1; stave <= play_movt->laststave; stave++)
               while (note->type == b_chord);
 
               /* Advance to start of following note */
-               
+
               nstart += length;
 
               /* If the note is followed by a tie, find the next note or
@@ -564,12 +599,12 @@ for (stave = 1; stave <= play_movt->laststave; stave++)
               accumulating will be output at the end of this bar. Set the
               noplay flag in the next notes, to stop them playing again
               later. Continue for multiple ties. */
-              
+
               while (note->type == b_tie)
                 {
                 int i, nlength;
                 note = misc_nextnote(note, NULL);
-              
+
                 if (note == NULL &&
                     play_bar + tiebarcount <= play_movt->barcount)
                   {
@@ -579,7 +614,7 @@ for (stave = 1; stave <= play_movt->laststave; stave++)
                     note = misc_nextnote(note, NULL);
                   }
                 if (note == NULL) break;
-              
+
                 nlength = note->length;
                 do
                   {
@@ -600,7 +635,7 @@ for (stave = 1; stave <= play_movt->laststave; stave++)
                     note->flags |= nf_noplay;
                     pitchstart[pitchcount++] = nstart;
                     }
-              
+
                   mac_advancechord(note);
                   }
                 while (note->type == b_chord);
@@ -608,7 +643,7 @@ for (stave = 1; stave <= play_movt->laststave; stave++)
                 }
 
               /* Handle some common scrubbing */
-              
+
               if (tremolo > 0 && !thisnotetied)
                 {
                 int ttype = (tremolo == or_trem1)? 1 : 2;
@@ -622,26 +657,26 @@ for (stave = 1; stave <= play_movt->laststave; stave++)
                 }
 
               for (scrubcount = 0; scrubcount < scrub; scrubcount++)
-                { 
+                {
                 int pc = pitchcount;
-  
+
                 /* For each required pitch, set up the events to make a sound.
                 The lengths may be different because of tied/non-tied notes in
                 chords, but these can only happen when not scrubbing. */
-                
+
                 while (--pc >= 0)
                   {
                   int pitch = pitchlist[pc] + playtranspose;
-                  int start = moff + pitchstart[pc] + 
+                  int start = moff - play_bar_moff + pitchstart[pc] +
                     scrubcount * (pitchlen[pc]/scrub);
-                
+
                   /* We have to schedule a note on and a note off event. Use
                   note on with zero velocity for note off, as that means
                   running status can be used. MIDI middle C is 60; PMW uses 48,
                   so first adjust the pitch. */
-                
+
                   pitch = midi_stave_pitch? midi_stave_pitch : (pitch + 12);
-                
+
                   next_event->time = start;
                   next_event->seq = next_event_seq++;
                   next_event->data[0] = 3;
@@ -649,7 +684,7 @@ for (stave = 1; stave <= play_movt->laststave; stave++)
                   next_event->data[2] = pitch;
                   next_event->data[3] = midi_stave_velocity;
                   next_event++;
-                
+
                   next_event->time = start + (pitchlen[pc]/scrub);
                   next_event->seq = next_event_seq++;
                   next_event->data[0] = 3;
@@ -658,7 +693,7 @@ for (stave = 1; stave <= play_movt->laststave; stave++)
                   next_event->data[3] = 0;
                   next_event++;
                   }
-                }   
+                }
               }
 
             stavetie[stave] = thisnotetied;
@@ -674,9 +709,10 @@ for (stave = 1; stave <= play_movt->laststave; stave++)
         }
       }
     }
+  NEXT_STAVE:
+  if (moff > maxmoff) maxmoff = moff;
   }
 
-
 /* Sort and output the items we've created, along with any events left over
 from the previous bar (ending tied notes). We relativize the times, and make
 use of running status. Stop when we hit either the end, or an event that is
@@ -724,7 +760,7 @@ next_event = neptr;
 
 /* Set time for start of next bar */
 
-last_written_time -= this_barlength;
+last_written_time -= (maxmoff - play_bar_moff);
 }
 
 
@@ -775,7 +811,7 @@ play_volume = 127;     /* PRO TEM */
 
 /* Stave selection is the main stave selection */
 
-for (i = 0; i < stave_bitvec_size; i++)
+for (i = 0; i < STAVE_BITVEC_SIZE; i++)
   play_staves[i] = play_movt->staves[i] & main_staves[i];
 
 /* Initialize the tie information */
@@ -842,7 +878,7 @@ writebyte(temp);
 
 /* Assign MIDI voices to MIDI channels if required. */
 
-for (i = 1; i <= midi_maxchannel; i++)
+for (i = 1; i <= MIDI_MAXCHANNEL; i++)
   {
   if (play_movt->midi_voice[i-1] < 128)
     {
@@ -963,14 +999,17 @@ for (play_bar = 1; play_bar < start_bar; play_bar++)
 /* Now write the bars */
 
 repeat_bar = play_bar;
+repeat_bar_moff = 0;
 repeat_endbar = -1;
 repeat_count = 1;
 
 for (play_bar = start_bar; play_bar <= end_bar;)
   {
   play_nextbar = play_bar + 1;
+  play_nextbar_moff = 0;
   writebar(play_bar == end_bar);
   play_bar = play_nextbar;
+  play_bar_moff = play_nextbar_moff;
   }
 
 /* Mark the end of the track, and fill in its length before closing the file */
