@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2008 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: December 2008 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains code for miscellanous functions used when paginating,
@@ -84,21 +84,32 @@ int
 misc_keywidth(int key, int clef)
 {
 pkeystr *pk;
+int width;
+int key63 = key & 63;
+
+DEBUG(("misc_keywidth() key=%d clef=%d\n", key, clef));
 
 for (pk = main_printkey; pk != NULL; pk = pk->next)
-  { if (key == pk->key && clef == pk->clef) break; }
+  { 
+  if (key63 == pk->key && clef == pk->clef && 
+      pk->movt_number <= curmovt->number) 
+    break; 
+  }
    
 if (pk != NULL)
   {
-  return string_width(pk->string, font_mf, 10000);
+  width = string_width((key>63)? pk->cstring : pk->string, font_mf, 10000);
   }
    
 else
   {       
-  int n = main_keysigtable[key & 63];
-  return abs(n) *
+  int n = main_keysigtable[key63];
+  width = abs(n) *
     (curmovt->accspacing)[(key>63)? ac_natural : (n>0)?ac_sharp : ac_flat];
   }   
+   
+DEBUG(("misc_keywidth() = %d\n", width));
+return width; 
 }
 
 
@@ -130,11 +141,12 @@ uschar *botstring = vd;
 if (!curmovt->showtime) return 0;
 
 /* First see if this time signature has special strings specified for its
-printing. */
+printing. The specification must have happened in this movement or earlier to 
+be applicable. */
 
 while (pt != NULL)
   {
-  if (pt->time == ts) break;
+  if (pt->time == ts && pt->movt_number <= curmovt->number) break;
   pt = pt->next;
   }
 
