@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains code for outputting a page */
@@ -572,7 +572,7 @@ for (stave = 1; stave <= out_laststave; stave++)
           (curmovt->startline)->clefspace, out_ystave,
             out_cont[stave].clef, 10000, FALSE);
 
-        if ((out_sysblock->cont[stave]).key != 2)
+        if (misc_keywidth(out_cont[stave].key, out_cont[stave].clef) != 0)
           out_writekey(out_sysblock->keyxposition + out_sysblock->xjustify,
             out_ystave, out_cont[stave].clef,
               out_cont[stave].key);
@@ -633,7 +633,7 @@ staves, unless there is only one stave. */
 
 if (out_sysblock->systemdepth > 0)
   {
-  int bracketed[stave_bitvec_size];
+  int bracketed[STAVE_BITVEC_SIZE];
   int bar = out_bar;
 
   DEBUG(("joining signs\n"));
