@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains code for splitting the music bars into systems and making
@@ -27,14 +27,14 @@ enum { page_state_newmovt, page_state_newsystem,
 *          Pagination function                   *
 *************************************************/
 
-/* This function is called when the music has been successfully read in to 
+/* This function is called when the music has been successfully read in to
 memory.
 
 Arguments:  none
 Returns:    nothing
 */
 
-void 
+void
 paginate_go(void)
 {
 int i;
@@ -111,12 +111,12 @@ page_botmargin = curmovt->botmargin;
 page_justify = curmovt->justify;
 page_topmargin = curmovt->topmargin;
 
-/* Working clefs while measuring. The current clef is needed only for measuring 
-special keys, which may depend on the clef. We can't use the page_cont versions 
-because they are not updated until after we know which bars are to be included 
+/* Working clefs while measuring. The current clef is needed only for measuring
+special keys, which may depend on the clef. We can't use the page_cont versions
+because they are not updated until after we know which bars are to be included
 in this system. */
 
-page_sysclef = store_Xget(sizeof(uschar) * (max_stave + 1));
+page_sysclef = store_Xget(sizeof(uschar) * (MAX_STAVE + 1));
 
 /* Loop that does the job; page_state controls which action is taken. */
 
@@ -135,13 +135,13 @@ while (!page_done) switch(page_state)
     {
     page_barlinewidth = (curmovt->notespacing)[minim]/2 - 5000;
     if (page_barlinewidth < 3000) page_barlinewidth = 3000;
-    curmovt->barlinespace = page_barlinewidth; 
+    curmovt->barlinespace = page_barlinewidth;
     }
   else page_barlinewidth = curmovt->barlinespace;
 
-  memcpy(page_stavemap, curmovt->staves, stave_bitvec_size*sizeof(int));
-  page_ulaysize = (curmovt->fontsizes)->fontsize_ulay;
-  page_olaysize = (curmovt->fontsizes)->fontsize_olay;
+  memcpy(page_stavemap, curmovt->staves, STAVE_BITVEC_SIZE*sizeof(int));
+  page_ulaysize = ((curmovt->fontsizes)->fontsize_text)[ff_offset_ulay];
+  page_olaysize = ((curmovt->fontsizes)->fontsize_text)[ff_offset_olay];
 
   /* Deal with heading texts if we know the movement is to go on this page. If
   we are at the top of a page, do the page heading unless it has been turned
@@ -163,12 +163,12 @@ while (!page_done) switch(page_state)
     (barposstr *)store_Xget(curmovt->barcount * sizeof(barposstr)) - 1;
 
   /* Now set up to process the bars. Start by finding the highest possible
-  stave number. */
+  stave number. If no staves are present in the movement, the result is -1. */
 
   page_lastwanted = -1;
     {
     int x;
-    for (i = stave_bitvec_size - 1; i >= 0; i--)
+    for (i = STAVE_BITVEC_SIZE - 1; i >= 0; i--)
       {
       if ((x = curmovt->staves[i]) != 0)
         {
@@ -190,7 +190,7 @@ while (!page_done) switch(page_state)
 
   /* Initialize values in the accepted data structure */
 
-  for (i = 0; i < stave_bitvec_size; i++)
+  for (i = 0; i < STAVE_BITVEC_SIZE; i++)
     page_accepteddata->notsuspend[i] = curmovt->staves[i] & (~curmovt->suspend[i]);
 
   memcpy(page_accepteddata->notespacing, curmovt->notespacing, 8*sizeof(int));
@@ -204,12 +204,13 @@ while (!page_done) switch(page_state)
     page_accepteddata->stavenames[i] = sn;
     }
 
-  /* Stavespacing is set only if it has been mentioned */
+  /* Stavespacing is set only if it has been mentioned. If not, set the
+  default. */
 
-  if (curmovt->stave_spacing == NULL)
+  if (curmovt->stave_spacing == NULL && page_lastwanted >= 0)
     {
     page_ssnext = store_Xget((page_lastwanted+1)*sizeof(int));
-    page_ssnext[0] = 0;
+    page_ssnext[0] = 0;  /* No space for stave 0 */
     for (i = 1; i <= page_lastwanted; i++) page_ssnext[i] = 44000;
     }
   else page_ssnext = curmovt->stave_spacing;
@@ -324,7 +325,7 @@ while (!page_done) switch(page_state)
     page_sysblock->flags = 0;
     page_sysblock->movt = curmovt;
     memcpy(page_sysblock->notsuspend, page_accepteddata->notsuspend,
-      stave_bitvec_size*sizeof(int));
+      STAVE_BITVEC_SIZE*sizeof(int));
     mac_initstave(page_sysblock->showtimes, 0);
     page_sysblock->barstart = page_barnumber;
     page_sysblock->barend = page_barnumber;
@@ -334,14 +335,14 @@ while (!page_done) switch(page_state)
 
     page_sysblock->cont = misc_copycontstr(page_cont, page_lastwanted, TRUE);
 
-    /* Set up working clefs at start of system; these are needed only for use 
-    when measuring the widths of special key signatures, which may depend on 
-    the clef. We can't use the page_cont values because they don't get updated 
+    /* Set up working clefs at start of system; these are needed only for use
+    when measuring the widths of special key signatures, which may depend on
+    the clef. We can't use the page_cont values because they don't get updated
     dynamically ('cause we don't want to go past the bars we accept). */
-      
+
     for (i = 1; i <= page_lastwanted; i++)
-      page_sysclef[i] = page_sysblock->cont[i].clef; 
- 
+      page_sysclef[i] = page_sysblock->cont[i].clef;
+
     page_sysblock->ulevel = store_Xget((page_lastwanted+1) * sizeof(int));
     page_sysblock->olevel = store_Xget((page_lastwanted+1) * sizeof(int));
 
@@ -370,17 +371,17 @@ while (!page_done) switch(page_state)
     page_accepteddata->endtime = FALSE;
     page_accepteddata->endbar = page_barnumber - 1;
     page_accepteddata->count = 0;
-    
+
     /* Save the initial notespacing so that it can be restored for re-spacing
     bars when there's a big stretch factor. */
-    
+
     memcpy(save_notespacing, page_accepteddata->notespacing, 8*sizeof(int));
 
     /* If all staves are suspended (can happen during part extraction with the
     use of [newline] or with S! bars) unsuspend the lowest numbered stave. If
     any staves get resumed in the system, this gets undone again later. */
 
-    if (!mac_anystave(page_sysblock->notsuspend)) for (i = 0; i < stave_bitvec_size; i++)
+    if (!mac_anystave(page_sysblock->notsuspend)) for (i = 0; i < STAVE_BITVEC_SIZE; i++)
       {
       if (curmovt->staves[i] != 0)
         {
@@ -473,7 +474,7 @@ while (!page_done) switch(page_state)
           if (tw > timewidth) timewidth = tw;
           }
         }
-      memcpy(page_sysblock->showtimes, page_showtimes, stave_bitvec_size * sizeof(int));
+      memcpy(page_sysblock->showtimes, page_showtimes, STAVE_BITVEC_SIZE * sizeof(int));
       mac_initstave(page_showtimes, 0);
       }
 
@@ -482,7 +483,7 @@ while (!page_done) switch(page_state)
     /* Set the first note position */
 
     page_sysblock->firstnoteposition =
-      timexposition + timewidth + page_leftbarspace + page_startline->notespace;
+      timexposition + timewidth + PAGE_LEFTBARSPACE + page_startline->notespace;
 
     /* The xposition is an absolute position, used during calculations */
 
@@ -523,13 +524,13 @@ while (!page_done) switch(page_state)
   of a system so that re-measuring the bar, for the next system, doesn't give a
   length warning again. If we back up two bars, in order to fit in a key/time
   signature, lengthwarn is set to 2. */
-  
+
   nextbarwidth = page_makepostable(lengthwarn-- < 1);
-  
+
   /* Compute position if bar were accepted */
 
   xposition = page_accepteddata->xposition + nextbarwidth;
-  
+
   /* If a stave has been resumed in this bar, or if a stave name has changed,
   it may be necessary to change the width of the stave name space (i.e.
   startxposition). This may make the bar unacceptable.
@@ -543,7 +544,7 @@ while (!page_done) switch(page_state)
 
   adjustkeyposition = 0;
   adjusttimeposition = 0;
-  
+
   if (mac_diffstave(page_nextdata->notsuspend, page_accepteddata->notsuspend) ||
       page_nextdata->stavenames != page_accepteddata->stavenames)
     {
@@ -602,16 +603,16 @@ while (!page_done) switch(page_state)
   accept one bar - it gets squashed (with a warning). If a fixed layout has
   been specified, accept bars until we have one more than required. */
 
-  if ((page_layoutptr < 0 && page_accepteddata->count > 0 && 
+  if ((page_layoutptr < 0 && page_accepteddata->count > 0 &&
         xposition > curmovt->linelength) ||
-      (page_layoutptr >= 0 && 
+      (page_layoutptr >= 0 &&
         page_accepteddata->count >= curmovt->layout[page_layoutptr]))
     {
     int overrun = xposition - curmovt->linelength;
-    lengthwarn = 1;       /* Don't warn when we reprocess the bar */ 
+    lengthwarn = 1;       /* Don't warn when we reprocess the bar */
 
     /* See if cautionary signature(s) are needed. */
-
+    
     if (!page_startlinebar && (page_warnkey || page_warntime))
       {
       xposition = page_accepteddata->xposition + page_xxwidth;
@@ -630,7 +631,7 @@ while (!page_done) switch(page_state)
           page_barcount -= page_lastbarcountbump;
           page_barnumber -= page_lastbarcountbump;
           overrun = xposition - curmovt->linelength;
-          lengthwarn++;   /* Two bars not to warn for */ 
+          lengthwarn++;   /* Two bars not to warn for */
           }
         else
           {
@@ -640,7 +641,7 @@ while (!page_done) switch(page_state)
         }
 
       /* Room for key/time -- set flag(s) and xposition */
-       
+
       else
         {
         page_accepteddata->xposition = xposition + page_barlinewidth;
@@ -688,11 +689,11 @@ while (!page_done) switch(page_state)
       page_previousdata->endkey = page_warnkey;
       page_previousdata->endtime = page_warntime;
       }
-    else 
+    else
       {
       page_previousdata->endkey = FALSE;
       page_previousdata->endtime = FALSE;
-      } 
+      }
 
     /* Allow for key & time signature positioning adjustment */
 
@@ -706,7 +707,7 @@ while (!page_done) switch(page_state)
     /* Update xposition, endbar number, and counts */
 
     page_accepteddata->xposition = xposition + page_barlinewidth;
-    
+
     if (page_manyrest >= 2)
       {
       page_accepteddata->endbar += page_manyrest;
@@ -742,9 +743,9 @@ while (!page_done) switch(page_state)
   case page_state_donesystem:
     {
     int startxposition = page_accepteddata->startxposition;
-    int barlinewidth = page_barlinewidth; 
+    int barlinewidth = page_barlinewidth;
     int justbits, stretchn, stretchd, sysdepth, sysfootdepth;
-    
+
     page_sysblock->stavenames = page_accepteddata->stavenames;
     page_sysblock->barend = page_accepteddata->endbar;
 
@@ -754,7 +755,7 @@ while (!page_done) switch(page_state)
     there was one. */
 
     if (mac_anystave(page_accepteddata->notsuspend))
-      for (i = 0; i < stave_bitvec_size; i++)
+      for (i = 0; i < STAVE_BITVEC_SIZE; i++)
         page_sysblock->notsuspend[i] = page_accepteddata->notsuspend[i];
 
     /* Fix various initial positions */
@@ -811,14 +812,14 @@ while (!page_done) switch(page_state)
             main_stretchthreshden) ||
               xposition > curmovt->linelength)
       {
-      int save_xxwidth = page_xxwidth; 
+      int save_xxwidth = page_xxwidth;
       int xxadjust = page_sysblock->firstnoteposition +
-        ((page_accepteddata->endkey || page_accepteddata->endtime)? 
+        ((page_accepteddata->endkey || page_accepteddata->endtime)?
           page_xxwidth + barlinewidth : 0);
 
       stretchn = curmovt->linelength - xxadjust;
       stretchd = xposition - xxadjust;
-      
+
       page_sysblock->xjustify = 0;
       page_sysblock->flags |= sysblock_stretch;
 
@@ -827,47 +828,47 @@ while (!page_done) switch(page_state)
       should not get any wider. Then compute revised stretching factors. Repeat
       if necessary, up to 4 times. Note that we have to keep re-stretching the
       barlinewidth.
-      
-      From release 4.22 we also do this when the stretching is actually 
+
+      From release 4.22 we also do this when the stretching is actually
       squashing by a large enough amount, which can happen when the layout
       directive forces more bars onto a line than would normally fit. This is
       necessary when there is underlay, where words might crash when a bar is
       squashed. (While testing this, it turns out that the squashing version
-      also sometimes kicks in after a stretching time round the loop, which 
+      also sometimes kicks in after a stretching time round the loop, which
       sometimes overdoes things, it seems. It does no harm.)
-       
+
       There's an option to prevent this new logic from happening, for old
-      files. It currently selects between three states: do nothing, do it only 
+      files. It currently selects between three states: do nothing, do it only
       for over-stretching, do it for both over-stretching and squashing. */
 
       page_layout_stretchn = stretchn;
       page_layout_stretchd = stretchn;   /* sic - see below - it changes cumulatively */
 
-      i = 0; 
+      i = 0;
       while (i++ < 4 &&
              (
-             (mac_muldiv(stretchd, 1000, stretchn) > main_stretchrespacethresh && 
+             (mac_muldiv(stretchd, 1000, stretchn) > main_stretchrespacethresh &&
                opt_stretchrule >= 2) ||
              (mac_muldiv(stretchn, 1000, stretchd) > main_stretchrespacethresh &&
                opt_stretchrule >= 1)
              ))
         {
-        int j; 
+        int j;
         page_layout_stretchd = mac_muldiv(page_layout_stretchd, stretchd, stretchn);
         xposition = page_sysblock->firstnoteposition;
         page_startlinebar = TRUE;        /* becomes FALSE after one acceptance */
         page_lastendwide = FALSE;        /* at start of line */
         page_lastenddouble = FALSE;      /* ditto */
-         
-        barlinewidth = mac_muldiv(barlinewidth, stretchn, stretchd); 
+
+        barlinewidth = mac_muldiv(barlinewidth, stretchn, stretchd);
         memcpy(page_nextdata->notespacing, save_notespacing, 8*sizeof(int));
-        
+
         /* Reset clefs at system start */
-         
+
         for (j = 1; j <= page_lastwanted; j++)
-          page_sysclef[j] = page_sysblock->cont[j].clef; 
-           
-        for (page_barnumber = page_sysblock->barstart; 
+          page_sysclef[j] = page_sysblock->cont[j].clef;
+
+        for (page_barnumber = page_sysblock->barstart;
              page_barnumber <= page_sysblock->barend;
              page_barnumber++)
           {
@@ -875,21 +876,21 @@ while (!page_done) switch(page_state)
           store_free(bp->vector);
           xposition += page_makepostable(FALSE) + barlinewidth;
           page_startlinebar = FALSE;
-          if (page_manyrest >= 2) page_barnumber += page_manyrest - 1; 
+          if (page_manyrest >= 2) page_barnumber += page_manyrest - 1;
           }
 
         xposition -= barlinewidth;
-        if (page_accepteddata->endkey || page_accepteddata->endtime) 
+        if (page_accepteddata->endkey || page_accepteddata->endtime)
           xposition += save_xxwidth + curmovt->barlinespace;  /* Unstretched barlinewidth */
         stretchd = xposition - xxadjust;
 
-        if (main_tracepos == (-1) || 
+        if (main_tracepos == (-1) ||
             (page_sysblock->barstart <= main_tracepos &&
-             page_sysblock->barend >= main_tracepos))  
+             page_sysblock->barend >= main_tracepos))
           debug_printf("i=%d bars %d-%d old=%d new=%d\n", i,
-            page_sysblock->barstart, page_sysblock->barend, 
-              mac_muldiv(page_layout_stretchn, 1000, page_layout_stretchd), 
-                mac_muldiv(stretchn, 1000, stretchd)); 
+            page_sysblock->barstart, page_sysblock->barend,
+              mac_muldiv(page_layout_stretchn, 1000, page_layout_stretchd),
+                mac_muldiv(stretchn, 1000, stretchd));
         }
       }
 
@@ -930,7 +931,7 @@ while (!page_done) switch(page_state)
       the bar. For big stretches, it is in fact not enough to do this, as the
       stretched barlinewidth can make their positioning look silly. We move
       them to the left in this case.
-      
+
       This is probably less relevant now that we re-lay-out lines to get the
       stretching factor down. */
 
@@ -1202,7 +1203,7 @@ while (!page_done) switch(page_state)
     curpage->spaceleft -= sysdepth + page_sysblock->systemgap;
     page_state = page_state_newsystem;
     page_lastsystem = page_sysblock;
-    
+
     /* Update the vertical justification parameters if they changed in this
     system. */
 
