@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 /* This is the main header file, imported by all other sources. */
 
@@ -31,6 +31,44 @@
 
 #define DEBUG(x) if (debugging) debug_printf x
 
+
+/*************************************************
+*                Program parameters              *
+*************************************************/
+
+#define DEF_MAX_BARS        500   /* Default max bars per movement */
+#define DRAW_BLOCKSIZE      256   /* Chunk size for draw routines */
+#define DRAW_STACKSIZE      100   /* Size of draw stack */
+#define LAYOUT_MAXSIZE      200   /* Max items in layout list */
+#define MAX_BEAMSIZE        100   /* Should be large enough for anything */
+#define MAX_CHORDSIZE        16   /* 16-note chords should be enough */
+#define MAX_DRAW_VARIABLE    19   /* Max number of a draw variable */
+#define MAX_FONTS            50   /* Maximum number of different fonts */
+#define MAX_INCLUDE          10   /* Max depth of included files */
+#define DEF_MAX_MOVEMENTS    50   /* Default max movements */
+#define MAX_POSTABLESIZE    400   /* Max number of entries */
+#define READ_BUFFERSIZE    1000   /* Input buffer size */
+#define MIDI_MAXCHANNEL      16   /* Maximum MIDI channel number */
+#define TEXT_QUEUE_SIZE      50   /* Max texts before a note */
+
+/* Maximum stave is defined in terms of the length of the bit vector
+that maps stave presence, suspension, etc. If STAVE_BITVEC_SIZE is
+increased, some tables in tables.c must also be extended. Also, the
+mac_initstave, mac_anystave and mac_samestave macros below must be
+suitably modified. */
+
+#define STAVE_BITVEC_SIZE     2   /* Number of ints in the bit vector */
+#define MAX_STAVE             (STAVE_BITVEC_SIZE * 32 - 1)
+
+/* Typesetting parameters */
+
+#define PAGE_LEFTBARSPACE  8000   /* Space at left of bar */
+
+
+/*************************************************
+*        Macros etc for character handling       *
+*************************************************/
+
 /* Some operating systems (naughtily, imo) include a definition for "uchar" in
 the standard header files, so we use "uschar". Solaris has u_char in
 sys/types.h. This is just a typing convenience, of course. */
@@ -228,39 +266,6 @@ typedef struct {
 
 
 
-/*************************************************
-*                Program parameters              *
-*************************************************/
-
-#define def_max_bars        500   /* Default max bars per movement */
-#define draw_blocksize      256   /* Chunk size for draw routines */
-#define draw_stacksize      100   /* Size of draw stack */
-#define layout_maxsize      200   /* Max items in layout list */
-#define max_beamsize        100   /* Should be large enough for anything */
-#define max_chordsize        10   /* 10-note chords should be enough */
-#define max_draw_variable    19   /* Max number of a draw variable */
-#define max_fonts            50   /* Maximum number of different fonts */
-#define max_include          10   /* Max depth of included files */
-#define def_max_movements    50   /* Default max movements */
-#define max_postablesize    400   /* Max number of entries */
-#define read_buffersize    1000   /* Input buffer size */
-#define midi_maxchannel      16   /* Maximum MIDI channel number */
-
-/* Maximum stave is defined in terms of the length of the bit vector
-that maps stave presence, suspension, etc. If stave_bitvec_size is
-increased, some tables in tables.c must also be extended. Also, the
-mac_initstave, mac_anystave and mac_samestave macros below must be
-suitably modified. */
-
-#define stave_bitvec_size     2   /* Number of ints in the bit vector */
-#define max_stave             (stave_bitvec_size * 32 - 1)
-
-/* Typesetting parameters */
-
-#define page_leftbarspace  8000   /* Space at left of bar */
-
-
-
 /*************************************************
 *                  Global Macros                 *
 *************************************************/
@@ -282,11 +287,11 @@ suitably modified. */
 
 /* If MaxExtraFont is increased, check that font_IdStrings in tables.c contains
 sufficient identifying strings, and that ps_IdStrings in ps.c is of the right
-size too. If MaxTextFont is changed, the initializing table init_fontsizes in
+size too. If MaxFontSizes is changed, the initializing table init_fontsizes in
 tables.c must be made to be the correct size. */
 
-#define MaxTextFont   12   /* for different text sizes */
-#define MaxExtraFont  12   /* for different faces */
+#define MaxFontSizes   12   /* for different text sizes */
+#define MaxExtraFont   12   /* for different faces */
 
 
 /* It is helpful to have names for the vertical offsets of the various lines
@@ -387,7 +392,7 @@ accidental on the relevant line or space. */
 #define mac_clearstave(a, z) \
   a[z >> 5] &= ~main_bit[z & 0x1f]
 
-/* Needs manual adjustment when stave_bitvec_size changes */
+/* Needs manual adjustment when STAVE_BITVEC_SIZE changes */
 #define mac_initstave(a, b) \
   a[0] = a[1] = b
 
@@ -410,15 +415,15 @@ accidental on the relevant line or space. */
 #define mac_testNstave2(a, b, z) \
   ((a[z >> 5] & b[z >> 5] & main_bit[z & 0x1f]) == 0)
 
-/* Needs manual adjustment when stave_bitvec_size changes */
+/* Needs manual adjustment when STAVE_BITVEC_SIZE changes */
 #define mac_anystave(a) \
   ((a[0] | a[1]) != 0)
 
-/* Needs manual adjustment when stave_bitvec_size changes */
+/* Needs manual adjustment when STAVE_BITVEC_SIZE changes */
 #define mac_diffstave(a, b) \
   (a[0] != b[0] || a[1] != b[1])
 
-/* Needs manual adjustment when stave_bitvec_size changes */
+/* Needs manual adjustment when STAVE_BITVEC_SIZE changes */
 #define mac_samestave(a, b) \
   (a[0] == b[0] && a[1] == b[1])
 
@@ -537,6 +542,16 @@ typedef struct {
 } fontstr;
 
 
+/* Offsets for special text font sizes and matrices, which follow in the same
+vector as sizes specified by the user. */
+
+#define ff_offset_ts     (MaxFontSizes)
+#define ff_offset_ulay   (ff_offset_ts+1)
+#define ff_offset_olay   (ff_offset_ulay+1)
+#define ff_offset_fbass  (ff_offset_olay+1)
+#define ff_offset_init   (ff_offset_fbass+1)
+#define SIZES_SIZE       (ff_offset_init+1)
+
 /* Structure for overall font sizes at standard magnification, and
 pointers to matrices for font stretching and shearing, where defined. */
 
@@ -550,16 +565,11 @@ typedef struct {
   int fontsize_footnote;
   int fontsize_rehearse;
   int fontsize_triplet;
-  int fontsize_repno;               /* repeat bar number */
-  int fontsize_restct;              /* long rest count */
-  int fontsize_trill;
-  int fontsize_vertacc;             /* vertical accidentals */
-  int fontsize_text[MaxTextFont];
-  int fontsize_tsfont;              /* These fonts are sometimes accessed  */
-  int fontsize_ulay;                /* as additional text fonts, using     */
-  int fontsize_olay;                /* the offsets defined below, so if    */
-  int fontsize_fbass;               /* changing, keep the offsets in step. */
-  int fontsize_init;                /* This one too...                     */
+  int fontsize_repno;                 /* repeat bar number */
+  int fontsize_restct;                /* long rest count */
+  int fontsize_trill;                 
+  int fontsize_vertacc;               /* vertical accidentals */
+  int fontsize_text[SIZES_SIZE];      /* vector of sizes */
 
   /* These must be in the same order as the font sizes, and music must
   be first. */
@@ -577,22 +587,9 @@ typedef struct {
   int *fontmatrix_restct;
   int *fontmatrix_trill;
   int *fontmatrix_vertacc;
-  int *fontmatrix_text[MaxTextFont];
-  int *fontmatrix_tsfont;
-  int *fontmatrix_ulay;
-  int *fontmatrix_olay;
-  int *fontmatrix_fbass;
-  int *fontmatrix_init;
+  int *fontmatrix_text[SIZES_SIZE];
 } fontsizestr;
 
-/* Offsets for special text fonts */
-
-#define ff_offset_ts     (MaxTextFont)
-#define ff_offset_ulay   (ff_offset_ts+1)
-#define ff_offset_olay   (ff_offset_ulay+1)
-#define ff_offset_fbass  (ff_offset_olay+1)
-#define ff_offset_init   (ff_offset_fbass+1)
-
 
 /* Data for spacing at the start of a line */
 
@@ -630,7 +627,8 @@ typedef struct snamestr {
 
 typedef struct ptimestr {
   struct ptimestr *next;
-  int   time;
+  int movt_number;          /* movement in which defined */ 
+  int time;
   uschar *top;
   uschar *bot;
   uschar  offsettop;
@@ -641,9 +639,11 @@ typedef struct ptimestr {
 
 typedef struct pkeystr {
   struct pkeystr *next;
+  int movt_number;          /* movement in which defined */ 
   int key;
   int clef;
   uschar *string;
+  uschar *cstring; 
 } pkeystr;
 
 /* One transposed key masquerade item */
@@ -690,9 +690,9 @@ typedef struct {
   int  moff;
   int  xoff;
   int  space;                       /* additional space required */
-  int  stemup[stave_bitvec_size];   /* bitmap of staves where there is an */
+  int  stemup[STAVE_BITVEC_SIZE];   /* bitmap of staves where there is an */
                                     /*  actual stem up, aka "posstaves" */
-  int  stemdown[stave_bitvec_size]; /* ditto for stem down */
+  int  stemdown[STAVE_BITVEC_SIZE]; /* ditto for stem down */
   int  auxid;                       /* identification of auxiliary items */
                                     /*  (may be -ve) */
  } workposstr;
@@ -723,7 +723,7 @@ typedef struct {
   int   endbar;                /* end bar number */
   int   count;                 /* count of bars */
   int   notespacing[8];        /* notespacing values */
-  unsigned int notsuspend[stave_bitvec_size];  /* not suspended staves */
+  unsigned int notsuspend[STAVE_BITVEC_SIZE];  /* not suspended staves */
   snamestr **stavenames;       /* stave name vector */
   CBOOL endkey;                /* line ends with key signature */
   CBOOL endtime;               /* line ends with time signature */
@@ -836,6 +836,7 @@ typedef struct {
   int   maxbeamslope1;
   int   maxbeamslope2;
   int   movt_opt;
+  int   number; 
   int   overlaydepth;
   int   play_tempo;
   int   rehearsalstyle;
@@ -855,9 +856,9 @@ typedef struct {
   int   underlaydepth;
   int   underlaystyle;
 
-  unsigned int breakbarlines[stave_bitvec_size];
-  unsigned int staves[stave_bitvec_size];
-  unsigned int suspend[stave_bitvec_size];
+  unsigned int breakbarlines[STAVE_BITVEC_SIZE];
+  unsigned int staves[STAVE_BITVEC_SIZE];
+  unsigned int suspend[STAVE_BITVEC_SIZE];
 
   int   clefwidths[clef_count];
   int   tailadjusts[8];
@@ -880,7 +881,7 @@ typedef struct {
   CBOOL underlayextenders;
   CBOOL unfinished;
 
-  signed char playtranspose[max_stave+1];
+  signed char playtranspose[MAX_STAVE+1];
 } movtstr;
 
 /* Layout of the data for an active line gap */
@@ -1022,9 +1023,9 @@ typedef struct sysblock {
   int       keyxposition;       /* position for key signature */
   int       timexposition;      /* position for time signature */
   int       firstnoteposition;  /* sic */
-  unsigned int notsuspend[stave_bitvec_size];
+  unsigned int notsuspend[STAVE_BITVEC_SIZE];
                                 /* staves not suspended in this system */
-  unsigned int showtimes[stave_bitvec_size];
+  unsigned int showtimes[STAVE_BITVEC_SIZE];
                                 /* staves which have starting time signatures */
   short int barstart;           /* starting bar number */
   short int barend;             /* ending bar number */
@@ -1206,7 +1207,7 @@ extern int  main_sheetheight;          /* Height of paper */
 extern int  main_sheetwidth;           /* Width of paper */
 extern BOOL main_shownlogo;            /* FALSE if need to show logo on error */
 extern int  main_stavemagn;            /* Magnification for current stave */
-extern int  main_staves[stave_bitvec_size]; /* External stave selection */
+extern int  main_staves[STAVE_BITVEC_SIZE]; /* External stave selection */
 extern int  main_storetotal;           /* Total store used */
 extern int  main_storestaves;          /* Store used for staves */
 extern int  main_stretchrespacethresh; /* Threshold for re-spacing */
@@ -1269,7 +1270,7 @@ extern stavestr **stavetable;          /* Points to pointers to stave struct */
 
 extern int  stave_bottoms[];           /* Levels of top/bottom lines of staves */
 extern int  stave_tops[];
-extern BOOL stave_use_draw;            /* Use direct drawing for staves */
+extern int  stave_use_draw;            /* Use direct drawing for staves */
 extern BOOL stave_use_widechars;       /* Use 100-pt chars for staves */
 
 extern const int     utf8_table1[];    /* Various tables for UTF-8 processing */
@@ -1316,7 +1317,7 @@ extern int   format_sprintf(uschar *, const char *, ...);      /* 2nd is format
 extern int   format_vsprintf(uschar *, const char *, va_list); /* ditto */
 
 extern void  info_printf(const char *, ...);
-extern int   init_command(int, char **, char ***, const char *);
+extern int   init_command(int, char **, char **, const char *);
 
 extern void  main_tidyup(void);
 
