@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains the main code for creating a position table for a bar. It
@@ -68,7 +68,7 @@ int MaxKeyWidth = 0;                       /* widest final key signature */
 int MaxTimeWidth = 0;                      /* widest final time signature */
 int Oldlastendwide = page_lastendwide;     /* previous bar's value */
 int Oldlastenddouble = page_lastenddouble; /* this for double bar */
-int ulaymap[stave_bitvec_size];            /* map underlay staves */
+int ulaymap[STAVE_BITVEC_SIZE];            /* map underlay staves */
 int largestmagn = 0;
 
 mac_initstave(ulaymap, 0);
@@ -254,8 +254,8 @@ for (page_stave = 0; page_stave <= page_lastwanted; page_stave++)
             int flags = note->flags;
             int notetype = note->notetype;
             int pitch = note->spitch;
-            int upflags[stave_bitvec_size];
-            int downflags[stave_bitvec_size];
+            int upflags[STAVE_BITVEC_SIZE];
+            int downflags[STAVE_BITVEC_SIZE];
 
             mac_initstave(upflags, 0);
             mac_initstave(downflags, 0);
@@ -331,7 +331,7 @@ for (page_stave = 0; page_stave <= page_lastwanted; page_stave++)
             /* Or in the stem flags and save extra space value if greater than
             what is there. */
 
-            for (i = 0; i < stave_bitvec_size; i++)
+            for (i = 0; i < STAVE_BITVEC_SIZE; i++)
               {
               pp->stemup[i] |= upflags[i];
               pp->stemdown[i] |= downflags[i];
@@ -1579,7 +1579,7 @@ else if (page_postable->auxid == posx_keyfirst ||
   page_xxwidth += (page_warnkey && page_warntime)?
     ((MaxKeyWidth > MaxTimeWidth)? MaxKeyWidth:MaxTimeWidth) :
     (page_warnkey? MaxKeyWidth : MaxTimeWidth); 
-
+    
   /* Add notespace to midline bars */
 
   /***  This would make the spacing as at line start, but stretching makes it
