@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains code for outputting things in PostScript */
@@ -485,7 +485,7 @@ for (;;)
     unsigned int pair;
 
     GETCHAR(cc, p);
-    pair = (c << 16) | cc;
+    pair = ((unsigned int)c << 16) | cc;
 
     while (bot < top)
       {
@@ -792,16 +792,18 @@ int x = leftx;
 
 /* Output the stave using PostScript drawing primitives. */
 
-if (stave_use_draw)
+if (stave_use_draw > 0)
   {
   int gap;
-  int thickness = (3*main_stavemagn)/10; 
+  int thickness = (stave_use_draw*main_stavemagn)/10; 
   
   if (ps_chcount > 0) ps_printf("\n");
   switch(stavelines)
     {
     case 1: y -= 4*main_stavemagn;
+    /* Fall through */ 
     case 2: y -= 4*main_stavemagn;
+    /* Fall through */ 
     case 3: gap = 8*main_stavemagn;
     break;
     
