@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 2nd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains part I of the code for reading in a PMW score file. */
@@ -24,7 +24,7 @@
 *************************************************/
 
 static int  read_count;
-static int  read_staves[stave_bitvec_size];   /* Map of staves actually read */
+static int  read_staves[STAVE_BITVEC_SIZE];   /* Map of staves actually read */
 static int  read_prevstave;                   /* Previous stave number */
 
 static BOOL read_in_quotes;
@@ -42,9 +42,9 @@ static pagestr dummy_page = { NULL, NULL, NULL, 1, 0, 0, 0 };
 *     Expand string with macros substitutions    *
 *************************************************/
 
-/* This is called for input lines, and also for the arguments of nested macro 
-calls. It copies the input string, expanding any macros encountered. If a 
-comment character is encountered, the rest of the line is copied, for error 
+/* This is called for input lines, and also for the arguments of nested macro
+calls. It copies the input string, expanding any macros encountered. If a
+comment character is encountered, the rest of the line is copied, for error
 messages, but the returned end value does not include the comment.
 
 Arguments:
@@ -53,10 +53,10 @@ Arguments:
   outbuffer     where to put the expanded line
   outlen        length of the output buffer
   addNL         if TRUE, add a newline character on the end
-  
+
 Returns:        pointer one past the end of the active part of the
                   expanded string in outbuffer
-*/     
+*/
 
 static uschar *
 expand_string(uschar *inptr, uschar *inend, uschar *outbuffer, int outlen,
@@ -106,9 +106,9 @@ while (inptr < inend)
           {
           if (s->data != NULL)
             {
-            macrostr *mm = (macrostr *)s->data; 
+            macrostr *mm = (macrostr *)s->data;
             int k = Ustrlen(mm->text);
-            
+
             /* Optimize the case with no arguments */
 
             if (mm->argcount == 0)
@@ -118,74 +118,74 @@ while (inptr < inend)
               Ustrcpy(temp, mm->text);
               temp += k;
               }
-            
+
             /* Otherwise have to process char by char, and read arguments, if
             any. */
-               
+
             else
               {
               int argcount = mm->argcount;
               uschar *pp = mm->text;
-              uschar *args[20]; 
+              uschar *args[20];
               uschar argbuff[2048];
-              uschar *ap = argbuff;  
-              
+              uschar *ap = argbuff;
+
               /* Set up the default arguments */
-               
-              for (i = 0; i < argcount; i++) args[i] = mm->args[i]; 
-              
+
+              for (i = 0; i < argcount; i++) args[i] = mm->args[i];
+
               /* Read given arguments, if any, increasing the count if more
               than the default number. */
-              
+
               if (*inptr == '(')
                 {
                 for (i = 0;; i++)
                   {
-                  int bracount = 0; 
-                  BOOL inquotes = FALSE; 
-                  uschar *ss = ap; 
-                  while (++inptr < inend && 
+                  int bracount = 0;
+                  BOOL inquotes = FALSE;
+                  uschar *ss = ap;
+                  while (++inptr < inend &&
                         ((*inptr != ',' && *inptr != ')') ||
-                          bracount > 0 || inquotes))  
+                          bracount > 0 || inquotes))
                     {
-                    int cch = *inptr; 
-                    if (cch == '&' && !isalnum(inptr[1])) 
-                      *ap++ = *(++inptr); 
+                    int cch = *inptr;
+                    if (cch == '&' && !isalnum(inptr[1]))
+                      *ap++ = *(++inptr);
                     else
-                      { 
-                      if (cch == '\"') inquotes = !inquotes; 
+                      {
+                      if (cch == '\"') inquotes = !inquotes;
                       if (!inquotes)
-                        { 
+                        {
                         if (cch == '(') bracount++;
-                          else if (cch == ')') bracount--; 
-                        }   
+                          else if (cch == ')') bracount--;
+                        }
                       *ap++ = cch;
-                      } 
+                      }
                     }
-                    
+
                   if (inptr >= inend) error_moan(99);
                   if (i >= argcount) { args[i] = NULL; argcount++; }
-                  if (ap - ss > 0) { *ap++ = 0; args[i] = ss; }  
-                    
+                  if (ap - ss > 0) { *ap++ = 0; args[i] = ss; }
+
                   if (inptr >= inend || *inptr == ')')
-                    { inptr++; break; } 
-                  } 
+                    { inptr++; break; }
+                  }
                 }
-                
+
               /* Process the arguments for nested macro calls */
-              
+
               for (i = 0; i < argcount; i++)
                 {
-                uschar *new_ap; 
+                uschar *new_ap;
                 if (args[i] == NULL || Ustrchr(args[i], '&') == NULL) continue;
                 new_ap = expand_string(args[i], args[i] + Ustrlen(args[i]),
-                  ap, argbuff + sizeof(argbuff) - ap, FALSE); 
+                  ap, argbuff + sizeof(argbuff) - ap, FALSE);
                 args[i] = ap;
                 ap = new_ap + 1;  /* final zero must remain */
-                }  
-                
-              /* Now copy the replacement, inserting the args */    
-                
+                }
+
+              /* Now copy the replacement, inserting the args */
+
               while (*pp != 0)
                 {
                 if (*pp == '&' && isdigit(pp[1]))
@@ -198,21 +198,21 @@ while (inptr < inend)
                     uschar *ss = args[arg];
                     if (ss != NULL)
                       {
-                      if (read_buffersize - 2 - (temp - outbuffer) <
-                        Ustrlen(ss)) error_moan(88);  /* hard */  
+                      if (READ_BUFFERSIZE - 2 - (temp - outbuffer) <
+                        Ustrlen(ss)) error_moan(88);  /* hard */
                       Ustrcpy(temp, ss);
-                      temp += Ustrlen(ss);    
-                      }   
-                    }     
+                      temp += Ustrlen(ss);
+                      }
+                    }
                   }
                 else
                   {
-                  if (temp - outbuffer + 2 >= outlen) 
+                  if (temp - outbuffer + 2 >= outlen)
                     error_moan(88);    /* hard error - buffer overflow */
-                  *temp++ = *pp++;    
-                  }       
-                }   
-              }  
+                  *temp++ = *pp++;
+                  }
+                }
+              }
             }
           }
         else error_moan(9, name);              /* Couldn't find name */
@@ -234,27 +234,27 @@ if (addNL)
   temp[0] = '\n';
   temp[1] = 0;
   }
-else *temp = 0;   
-  
-/* Return the end of the active data */  
+else *temp = 0;
+
+/* Return the end of the active data */
 
 return comment? comment : temp;
-}   
+}
 
 
 /*************************************************
 *                Read next character             *
 *************************************************/
 
-/* This function updates the global variable read_ch with the next character, 
-including a newline at the end of each line. It deals with macro expansions and 
+/* This function updates the global variable read_ch with the next character,
+including a newline at the end of each line. It deals with macro expansions and
 preprocessing directives, and it skips comments.
 
 Arguments: none
 Returns:   nothing
 */
 
-void 
+void
 next_ch(void)
 {
 for (;;)   /* Loop until a character is obtained or very end is reached */
@@ -284,12 +284,12 @@ for (;;)   /* Loop until a character is obtained or very end is reached */
   for (;;)
     {
     if (input_file != NULL)
-      {  
-      if (Ufgets(this_buffer, read_buffersize - 4, input_file) != NULL) break;
+      {
+      if (Ufgets(this_buffer, READ_BUFFERSIZE - 4, input_file) != NULL) break;
       fclose(input_file);
       input_file = NULL;
       }
-         
+
     Ustrcpy(this_buffer, "--- End of file ---");  /* for reflection */
     read_chptr = this_buffer + 19;                /* just in case */
     read_endptr = read_chptr + 1;                 /* nothing left */
@@ -306,7 +306,7 @@ for (;;)   /* Loop until a character is obtained or very end is reached */
       }
 
     /* Pop stack at end of included file */
-    
+
     DEBUG(("end of %s: popping include stack\n", main_filename));
     store_free(main_filename);
     main_filename = read_filestack[--read_filestackptr].filename;
@@ -318,7 +318,7 @@ for (;;)   /* Loop until a character is obtained or very end is reached */
 
   /* Another line has been read; take care with the final one which may not
   have a newline on the end. */
-  
+
   read_linenumber++;
   len = Ustrlen(this_buffer);
 
@@ -326,7 +326,7 @@ for (;;)   /* Loop until a character is obtained or very end is reached */
   read_chptr  = this_buffer;
   read_endptr = this_buffer + len;
 
-  if (len >= read_buffersize - 5) error_moan(81);  /* give-up error */
+  if (len >= READ_BUFFERSIZE - 5) error_moan(81);  /* give-up error */
 
   if (len > 0 && read_endptr[-1] == '\n') read_endptr--;
 
@@ -337,9 +337,9 @@ for (;;)   /* Loop until a character is obtained or very end is reached */
   if (read_skipdepth <= 0)
     {
     uschar *temp;
-    read_endptr = expand_string(read_chptr, read_endptr, next_buffer, 
-      read_buffersize, TRUE);
-      
+    read_endptr = expand_string(read_chptr, read_endptr, next_buffer,
+      READ_BUFFERSIZE, TRUE);
+
     /* Swap this buffer and next buffer, initialize pointer. */
 
     temp = this_buffer;
@@ -379,7 +379,7 @@ Argument:   where to put the word
 Returns:    nothing
 */
 
-void 
+void
 read_word(uschar *word)
 {
 int i = 0;
@@ -405,13 +405,13 @@ word[i] = 0;
 
 /* This procedure is used for reading file names and the like
 in heading directives. These are in quotes, but are not to be
-interpreted as PMW strings. 
+interpreted as PMW strings.
 
 Argument:    where to put the string
 Returns:     TRUE if OK, FALSE if quote missing
 */
 
-BOOL 
+BOOL
 read_plainstring(uschar *s)
 {
 sigch();
@@ -438,10 +438,10 @@ return TRUE;
 /* Called when the first character is known to be a digit or a dot.
 
 Argument:    TRUE to read a fixed point number; FALSE for an integer
-Returns:     the value 
+Returns:     the value
 */
 
-int 
+int
 read_integer(BOOL fixed)
 {
 int yield = 0;
@@ -483,11 +483,11 @@ Arguments:
   yield       where to put the value
   fixed       TRUE for a fixed point value, FALSE for an integer
   allowsign   TRUE if a sign is permitted
-  
+
 Returns:      TRUE if OK, FALSE on error
 */
 
-BOOL 
+BOOL
 read_expect_integer(int *yield, int fixed, int allowsign)
 {
 int sign = 1;
@@ -521,7 +521,7 @@ Arguments:   none
 Returns:     the value, or zero after an error
 */
 
-int 
+int
 read_movevalue(void)
 {
 int x;
@@ -542,7 +542,7 @@ Arguments:  none
 Returns:    the keysignature or zero on error
 */
 
-int 
+int
 read_key(void)
 {
 int key = 0;
@@ -567,14 +567,16 @@ return key;
 *            Double/halve time signature         *
 *************************************************/
 
-/* The global variables main_notenum and main_noteden contain the numerator and 
-denominator of any time scaling that has been set up.
+/* The global variables main_notenum and main_noteden contain the numerator and
+denominator of any note scaling (doublenotes, halvenotes) that was set up in
+the movement's header. This affects time signatures. The stave directives 
+[doublenotes] and [halvenotes] do not affect time signatures.
 
 Argument:   the time signature
 Returns:    the scaled time signature
 */
 
-int 
+int
 read_scaletime(int ts)
 {
 int m, n, d;
@@ -590,16 +592,16 @@ if (d == time_common || d == time_cut)
   if (main_noteden > 1)
     {
     if (m%main_noteden == 0) m /= main_noteden;
-      else error_moan(102); 
-    }    
-  return (m << 16) | d;  
+      else error_moan(102);
+    }
+  return (m << 16) | d;
   }
 
 d *= main_noteden;
 if (d % main_notenum == 0) d /= main_notenum;
   else n *= main_notenum;
-  
-return (m << 16) + (n << 8) + d; 
+
+return (m << 16) + (n << 8) + d;
 }
 
 
@@ -614,10 +616,10 @@ Arguments:  none
 Returns:    the packed up time signature
 */
 
-int 
+int
 read_time(void)
 {
-int gotnum = FALSE;
+BOOL gotnum = FALSE;
 int m, n, d;
 
 sigch();
@@ -636,7 +638,7 @@ else m = 1;
 
 if (!gotnum)
   {
-  read_ch = tolower(read_ch); 
+  read_ch = tolower(read_ch);
   if (read_ch == 'a' || read_ch == 'c')
     {
     int type = (read_ch == 'c')? time_common : time_cut;
@@ -645,7 +647,7 @@ if (!gotnum)
     }
   if (!read_expect_integer(&n, FALSE, FALSE)) return 0;
   }
-   
+
 sigch();
 if (read_ch != '/')
   {
@@ -655,9 +657,7 @@ if (read_ch != '/')
 
 next_ch();
 if (!read_expect_integer(&d, FALSE, FALSE)) return 0;
-
 if (d < 1 || d > 64 || d != (d & (-d))) error_moan(87); /* hard error */
-
 return read_scaletime((m << 16) | (n << 8) | d);
 }
 
@@ -667,12 +667,12 @@ return read_scaletime((m << 16) | (n << 8) | d);
 *      Compute barlength from time signature     *
 *************************************************/
 
-/* 
+/*
 Argument:  the time signature
 Returns:   the bar length
 */
 
-int 
+int
 read_compute_barlength(int ts)
 {
 int m = (ts >> 16) & 255;
@@ -691,39 +691,39 @@ return n * m * (len_semibreve/d);
 *       Get MIDI number from string              *
 *************************************************/
 
-/* This function scans a list of MIDI voice or percussion names to find the 
-number for a given name. If we are not generating MIDI (midi_filename is NULL), 
+/* This function scans a list of MIDI voice or percussion names to find the
+number for a given name. If we are not generating MIDI (midi_filename is NULL),
 there is no search, but we do not give an error. Just return zero.
 
 Arguments:
   list        the list of MIDI names
   string      the string to search for
   text        text for use in the error message
-  
-Returns:      the MIDI number
-*/   
 
-int 
+Returns:      the MIDI number
+*/
+
+int
 read_getmidinumber(uschar *list, uschar *string, uschar *text)
 {
 int yield = -1;
 
 if (list != NULL) while (*list)
   {
-  int len = Ustrlen(list); 
+  int len = Ustrlen(list);
   if (Ustrcmp(list, string) == 0)
     {
     yield = list[len+1];
-    break;  
+    break;
     }
-  list += len + 2;      
-  } 
-  
+  list += len + 2;
+  }
+
 if (yield < 0)
   {
-  if (midi_filename != NULL) error_moan(110, text, string); 
+  if (midi_filename != NULL) error_moan(110, text, string);
   yield = 0;
-  }   
+  }
 
 return yield;
 }
@@ -735,24 +735,25 @@ return yield;
 *      Start of movement initialization          *
 *************************************************/
 
-/* This function resets values that must be reset at the start of every 
-movement. Other per-movement data is initialized to default values (the 
-init_movtstr variable) for the first movement, then copied to subsequent 
+/* This function resets values that must be reset at the start of every
+movement. Other per-movement data is initialized to default values (the
+init_movtstr variable) for the first movement, then copied to subsequent
 movements.
 
 Argument:   option for type of movement (same page, new page, etc)
 Returns:    nothing
 */
 
-static 
+static
 void init_movt(int opt)
 {
 int i;
-curmovt->stavetable = store_Xget((max_stave+1) * sizeof(stavestr *));
+curmovt->stavetable = store_Xget((MAX_STAVE+1) * sizeof(stavestr *));
 
 stavetable = curmovt->stavetable;
-for (i = 0; i <= max_stave; i++) stavetable[i] = NULL;
+for (i = 0; i <= MAX_STAVE; i++) stavetable[i] = NULL;
 
+curmovt->number = main_lastmovement;
 curmovt->barcount = 0;
 curmovt->baroffset = 0;
 curmovt->barnovector = NULL;           /* Got when first stave encountered */
@@ -770,7 +771,7 @@ curmovt->posvector = NULL;
 curmovt->showtime = TRUE;
 curmovt->startbracketbar = 0;
 curmovt->startnotime = FALSE;
-memcpy(curmovt->staves, main_staves, stave_bitvec_size*sizeof(int));
+memcpy(curmovt->staves, main_staves, STAVE_BITVEC_SIZE*sizeof(int));
 curmovt->time = 0x00010404;            /* 1*4/4 */
 curmovt->transpose = main_transpose;
 curmovt->unfinished = FALSE;
@@ -807,11 +808,11 @@ Arguments:   none
 Returns:     nothing
 */
 
-static void 
+static void
 read_endmovement(void)
 {
 int i;
-for (i = 0; i < stave_bitvec_size; i++)
+for (i = 0; i < STAVE_BITVEC_SIZE; i++)
   curmovt->staves[i] &= read_staves[i];      /* Disable those not read */
 
 /* If there was a playtempo directive, adjust the bar numbers so that they are
@@ -849,15 +850,15 @@ if (curmovt->play_tempo_changes != NULL)
 *         Top-level reading control              *
 *************************************************/
 
-/* Called from the main control function. This function reads the input stream, 
-alternating between heading directives and music staves for the different 
+/* Called from the main control function. This function reads the input stream,
+alternating between heading directives and music staves for the different
 movements that are present.
 
 Arguments:  none
 Returns:    nothing
 */
 
-void 
+void
 read_go(void)
 {
 DEBUG(("read_go() start\n"));
@@ -905,7 +906,6 @@ if (main_rc < rc_failed) for (;;)
     next_ch();
     read_word(word);
 
-
     /* It's another stave. Check that a valid number is given. If so, set up
     the index for its bars and get ready to read the rest of the data. */
 
@@ -920,8 +920,8 @@ if (main_rc < rc_failed) for (;;)
 
       /* Error if number too big or stave supplied twice */
 
-      if (curstave > max_stave) 
-        { error_moan(22, max_stave+1); break; }  
+      if (curstave > MAX_STAVE)
+        { error_moan(22, MAX_STAVE+1); break; }
       if (stavetable[curstave] != NULL)
         { error_moan(31, curstave); break; }
 
@@ -964,23 +964,25 @@ if (main_rc < rc_failed) for (;;)
       stave_couplestate = stave_octave = 0;
       stave_notes = TRUE;
       stave_noteflags = (curstave == 0)? nf_hidden : 0;
+      stave_notenum = main_notenum;
+      stave_noteden = main_noteden;  
       stave_matchnum = 0; /* indicates "unset" */
-      stave_totalnocount = stave_slurcount = 
+      stave_totalnocount = stave_slurcount =
         stave_hairpinbegun = stave_hairpiny = 0;
       stave_stemforce = stave_ties = stave_textflags = 0;
       stave_textabsolute = 0;
       stave_accentflags = stave_restlevel = stave_stemlength = 0;
       stave_pletflags = stave_plety = 0;
       stave_ornament = -1;
-      stave_printpitch = 0; 
+      stave_printpitch = 0;
       stave_stemflag = nf_stem;
       stave_pendulay = NULL;
       stave_hairpinflags = hp_below;
-      stave_hairpinwidth = curmovt->hairpinwidth; 
+      stave_hairpinwidth = curmovt->hairpinwidth;
 
       stave_clef = clef_treble;
       stave_clef_octave = 0;
-      stave_barlinestyle = curmovt->barlinestyle; 
+      stave_barlinestyle = curmovt->barlinestyle;
 
       stave_transposedaccforce = main_transposedaccforce;
       stave_transpose = curmovt->transpose;
@@ -1011,9 +1013,9 @@ if (main_rc < rc_failed) for (;;)
 
       stave_suspended = mac_teststave(curmovt->suspend, curstave);
       stave_stemswaplevel = curmovt->stemswaplevel;
-      
+
       read_prev_had_dbar = read_prev_had_ibar = FALSE;
-      read_prev_barlinestyle = stave_barlinestyle;  
+      read_prev_barlinestyle = stave_barlinestyle;
 
 
       /* Set the bar number, and enter the normal reading state, with a
@@ -1022,7 +1024,7 @@ if (main_rc < rc_failed) for (;;)
       stave_barnumber = 1;
       read_stavestart = read_endstave = FALSE;
       sigch();
-      if (read_ch == '\"' || (read_ch == 'd' && Ustrncmp(read_chptr, "raw ", 4) == 0)) 
+      if (read_ch == '\"' || (read_ch == 'd' && Ustrncmp(read_chptr, "raw ", 4) == 0))
         Ustrcpy(read_stavedir, "name");
           else read_stavedir[0] = 0;
       read_chptr--;
@@ -1037,9 +1039,9 @@ if (main_rc < rc_failed) for (;;)
       {
       int opt = movt_default;
       int ph = 0;
-      int lf = 0; 
+      int lf = 0;
       movtstr *newcurmovt;
-      
+
       if (main_lastmovement >= main_max_movements)
         { error_moan(120, main_max_movements); break; }   /* disaster */
 
@@ -1052,7 +1054,7 @@ if (main_rc < rc_failed) for (;;)
         else if (Ustrcmp(word, "thisline") == 0) opt = movt_thisline;
         else if (Ustrcmp(word, "newpage") == 0) opt = movt_newpage;
         else if (Ustrcmp(word, "nopageheading") == 0) ph = movt_nopageheading;
-        else if (Ustrcmp(word, "uselastfooting") == 0) lf = movt_uselastfooting; 
+        else if (Ustrcmp(word, "uselastfooting") == 0) lf = movt_uselastfooting;
         else error_moan(10,
           "\"thispage\", \"thisline\", \"newpage\", \"nopageheading\", or \"uselastfooting\"");
         }
@@ -1143,13 +1145,13 @@ store_free(read_stavedir);
 
 if (input_file != NULL) fclose(input_file);
 while (read_filestackptr > 0) fclose(read_filestack[--read_filestackptr].file);
-  
+
 /* Warn if the format word was never tested. By giving the error after
 resetting reading_input, it won't try to reflect the input line. */
 
 reading_input = FALSE;
 if (main_format[0] != 0 && !main_format_tested) error_moan(104, main_format);
-  
+
 DEBUG(("read_go() end\n"));
 }
 
@@ -1159,27 +1161,27 @@ DEBUG(("read_go() end\n"));
 *          Set up for reading routines           *
 *************************************************/
 
-/* This function is called at the start of reading. 
+/* This function is called at the start of reading.
 
 Arguments:  none
 Returns:    nothing
 */
 
-void 
+void
 read_start(void)
 {
 int i;
 
 /* Stack for included files */
 
-read_filestack = store_Xget(max_include*sizeof(filestr));
+read_filestack = store_Xget(MAX_INCLUDE*sizeof(filestr));
 
 /* Set up buffers for line reading */
 
 read_stavedir = store_Xget(64);
-next_buffer = store_Xget(read_buffersize);
-this_buffer = store_Xget(read_buffersize);
-prev_buffer = store_Xget(read_buffersize);
+next_buffer = store_Xget(READ_BUFFERSIZE);
+this_buffer = store_Xget(READ_BUFFERSIZE);
+prev_buffer = store_Xget(READ_BUFFERSIZE);
 this_buffer[0] = prev_buffer[0] = 0;
 
 /* Variables for controlling reading of the file */
@@ -1199,6 +1201,7 @@ memcpy(main_notespacing, init_notespacing, 8*sizeof(int));
 
 /* Initialize movement table for first movement */
 
+main_lastmovement = 1;
 for (i = 0; i <= main_max_movements; i++) movement[i] = NULL;
 curmovt = movement[1] = store_Xget(sizeof(movtstr));
 *curmovt = init_movtstr;       /* Default settings */
@@ -1223,21 +1226,22 @@ for (i = font_xx; i < font_xx + MaxExtraFont; i++)
 
 if (font_table[font_rm] < 0 || font_table[font_mf] < 0)
   error_moan(25);    /* Hard */
-  
+
 /* Point current page at a dummy (relevant for string escape checking) */
 
-curpage = &dummy_page; 
+curpage = &dummy_page;
 
 /* Miscellaneous start-of-file initialization */
 
 baraccs = store_Xget(baraccs_len);
 baraccs_tp = store_Xget(baraccs_len);
-stave_tiedata = store_Xget(max_chordsize * sizeof(tiedata));
+stave_tiedata = store_Xget(MAX_CHORDSIZE * sizeof(tiedata));
 
 stave_beamstack = store_Xget(beamstacksize);
 stave_stemstack = store_Xget(stemstacksize);
+beam_overbeam = FALSE;  /* For misc_nextnote() while reading */
 
-page_postable = store_Xget(max_postablesize * sizeof(workposstr));
+page_postable = store_Xget(MAX_POSTABLESIZE * sizeof(workposstr));
 
 define_tree = draw_tree = draw_variable_tree = NULL;
 draw_thickness = 500;
@@ -1250,7 +1254,6 @@ main_firstpage = main_pageinc = 1;
 main_format_tested = FALSE;
 main_htypes = NULL;
 main_kerning = TRUE;
-main_lastmovement = 1;
 main_magnification = 1000;
 main_maxvertjustify = 60000;
 main_pageanchor = NULL;
@@ -1258,7 +1261,7 @@ main_printkey = NULL;
 main_printtime = NULL;
 main_pssetup = NULL;
 main_sheetheight = 842000;
-main_sheetwidth = 595000; 
+main_sheetwidth = 595000;
 opt_sheetsize = sheet_A4;
 opt_stretchrule = 2;               /* The latest rule */
 main_transposedaccforce = TRUE;
@@ -1267,7 +1270,7 @@ main_truepagelength = 720000;
 
 draw_lgx = draw_lgy = 0;
 
-out_depthvector = store_Xget((max_stave+1) * sizeof(int *));
+out_depthvector = store_Xget((MAX_STAVE+1) * sizeof(int *));
 
 font_reset();        /* To set no transformation */
 font_xstretch = 0;   /* No justification */
