@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains part II of the code for reading in a PMW score file. It
@@ -72,7 +72,7 @@ enum {
 *          Local static variables                *
 *************************************************/
 
-static int read_map[stave_bitvec_size];  /* For reading lists of staves */
+static int read_map[STAVE_BITVEC_SIZE];  /* For reading lists of staves */
 
 
 /*************************************************
@@ -155,8 +155,8 @@ if (isdigit(read_ch))
 
   *sizeptr = read_integer(TRUE);
   *matrixptr = NULL;
-  
-  /* Handle stretch and shear */ 
+
+  /* Handle stretch and shear */
 
   if (read_ch == '/')
     {
@@ -307,7 +307,7 @@ while (isdigit(read_ch))
     }
 
   if (t < s) error_moan(21);
-    else if (t > max_stave) error_moan(22, max_stave+1);
+    else if (t > MAX_STAVE) error_moan(22, MAX_STAVE+1);
   else
     {
     stave_list *q = store_Xget(sizeof(stave_list));
@@ -347,7 +347,7 @@ while (isdigit(read_ch))
     }
 
   if (t < s) error_moan(21);
-    else if (t > max_stave) error_moan(22, max_stave + 1);
+    else if (t > MAX_STAVE) error_moan(22, MAX_STAVE + 1);
       else while (s <= t) { mac_setstave(read_map, s); s++; }  /* Can't put */
                                                                /* s++ inside */
   sigchNL();
@@ -356,7 +356,7 @@ while (isdigit(read_ch))
 
 if (read_dir->arg1 != 0)
   memcpy(((uschar *)curmovt) + read_dir->arg1, read_map,
-    stave_bitvec_size*sizeof(int));
+    STAVE_BITVEC_SIZE*sizeof(int));
 }
 
 
@@ -961,7 +961,7 @@ if (main_lastmovement != 1) error_moan(20);
 static void
 layout(void)
 {
-int *temp = store_Xget(layout_maxsize * 2 * sizeof(int));
+int *temp = store_Xget(LAYOUT_MAXSIZE * 2 * sizeof(int));
 int stack[20];
 int ptr = 0;
 int level = 0;
@@ -1111,9 +1111,9 @@ debug_printf("midichannel start\n");
 
 if (!read_expect_integer(&channel, FALSE, FALSE)) return;
 
-if (channel < 1 || channel > midi_maxchannel)
+if (channel < 1 || channel > MIDI_MAXCHANNEL)
   {
-  error_moan(109, "channel", midi_maxchannel);
+  error_moan(109, "channel", MIDI_MAXCHANNEL);
   channel = 1;
   }
 
@@ -1133,7 +1133,7 @@ if (read_plainstring(string))
       }
     }
 
-  copy_midi_map(rh_midivoice, midi_maxchannel, &(curmovt->midi_voice));
+  copy_midi_map(rh_midivoice, MIDI_MAXCHANNEL, &(curmovt->midi_voice));
   curmovt->midi_voice[channel-1] = voicenumber - 1;
 
   /* There may be an optional volume setting */
@@ -1146,7 +1146,7 @@ if (read_plainstring(string))
       {
       if (vol > 15) error_moan(10, "Number between 0 and 15"); else
         {
-        copy_midi_map(rh_midivolume, max_stave+1, &(curmovt->midi_volume));
+        copy_midi_map(rh_midivolume, MIDI_MAXCHANNEL, &(curmovt->midi_volume));
         curmovt->midi_volume[channel-1] = vol;
         }
       }
@@ -1161,7 +1161,7 @@ if (isdigit(read_ch))
   int i;
   int pitch = 0;
 
-  copy_midi_map(rh_midichannel, max_stave+1, &(curmovt->midi_channel));
+  copy_midi_map(rh_midichannel, MAX_STAVE+1, &(curmovt->midi_channel));
 
   movt_mapproc();    /* read stave list into read_map */
 
@@ -1172,12 +1172,12 @@ if (isdigit(read_ch))
     if (string[0] == 0) pitch = 0;  /* => don't do MIDI pitch forcing */
       else if (string[0] == '#') pitch = Uatoi(string+1);
         else pitch = read_getmidinumber(midi_percnames, string, US"percussion instrument");
-    copy_midi_map(rh_midinote, max_stave+1, &(curmovt->midi_note));
+    copy_midi_map(rh_midinote, MAX_STAVE+1, &(curmovt->midi_note));
     }
 
   /* Now update the per-stave data */
 
-  for (i = 1; i <= max_stave; i++)
+  for (i = 1; i <= MAX_STAVE; i++)
     {
     if (mac_teststave(read_map, i))
       {
@@ -1273,6 +1273,7 @@ else
 }
 
 
+
 /*************************************************
 *            Oldstretchrule                      *
 *************************************************/
@@ -1414,8 +1415,8 @@ if (v > 15)
   return;
   }
 
-curmovt->play_volume = vv = store_Xget(max_stave + 1);
-for (i = 1; i <= max_stave; i++) vv[i] = v;
+curmovt->play_volume = vv = store_Xget(MAX_STAVE + 1);
+for (i = 1; i <= MAX_STAVE; i++) vv[i] = v;
 
 /* Now look for additional data giving stave volumes */
 
@@ -1486,7 +1487,7 @@ if (read_ch == '/')
     {
     next_ch();
     if (!read_expect_integer(&fo, FALSE, FALSE)) return FALSE;
-    if ((fo -= 1) >= MaxTextFont) error_moan(39, MaxTextFont);
+    if ((fo -= 1) >= MaxFontSizes) error_moan(39, MaxFontSizes);
     }
   else
     {
@@ -1508,6 +1509,7 @@ printtime(void)
 {
 ptimestr *p = store_Xget(sizeof(ptimestr));
 p->next = main_printtime;
+p->movt_number = main_lastmovement;
 main_printtime = p;
 if ((p->time = read_time()) == 0) return;
 if (!ptstring(&(p->top), &(p->offsettop))) return;
@@ -1524,15 +1526,16 @@ printkey(void)
 {
 pkeystr *p = store_Xget(sizeof(pkeystr));
 p->next = main_printkey;
+p->movt_number = main_lastmovement;
 main_printkey = p;
 p->key = read_key();
 p->clef = read_clef();
 p->string = string_check(string_read());
+sigch();
+p->cstring = (read_ch == '"')? string_check(string_read()) : US"";
 }
 
 
-
-
 /*************************************************
 *                 Pssetup                        *
 *************************************************/
@@ -1684,8 +1687,8 @@ read_expect_integer(&curmovt->startbracketbar, FALSE, FALSE);
 static void
 stavesize(void)
 {
-int *stavesizes = store_Xget((max_stave+1)*sizeof(int));
-memcpy(stavesizes, curmovt->stavesizes, (max_stave+1)*sizeof(int));
+int *stavesizes = store_Xget((MAX_STAVE+1)*sizeof(int));
+memcpy(stavesizes, curmovt->stavesizes, (MAX_STAVE+1)*sizeof(int));
 curmovt->stavesizes = stavesizes;
 
 sigch();
@@ -1693,7 +1696,7 @@ while (isdigit(read_ch))
   {
   int size;
   int stave = read_integer(FALSE);
-  if (stave > max_stave) { error_moan(22, max_stave+1); stave = 1; }
+  if (stave > MAX_STAVE) { error_moan(22, MAX_STAVE+1); stave = 1; }
   if (read_ch != '/') { error_moan(10, "/"); return; }
   next_ch();
   if (!read_expect_integer(&size, TRUE, FALSE)) return;
@@ -1713,14 +1716,14 @@ stavespacing(void)
 {
 BOOL first = TRUE;
 int i;
-int *newsp = store_Xget((max_stave+1) * sizeof(int));
-int *newen = store_Xget((max_stave+1) * sizeof(int));
-unsigned int done[stave_bitvec_size];
+int *newsp = store_Xget((MAX_STAVE+1) * sizeof(int));
+int *newen = store_Xget((MAX_STAVE+1) * sizeof(int));
+unsigned int done[STAVE_BITVEC_SIZE];
 
 newsp[0] = newen[0] = 0;
 mac_initstave(done, 0);
 
-for (i = 1; i <= max_stave; i++)
+for (i = 1; i <= MAX_STAVE; i++)
   {
   newsp[i] = 44000;
   newen[i] = 0;
@@ -1741,7 +1744,7 @@ while (isdigit(read_ch))
       {
       space = stave*1000;
       if (read_ch == '.') space += read_integer(TRUE);
-      for (i = 1; i <= max_stave; i++) newsp[i] = space;
+      for (i = 1; i <= MAX_STAVE; i++) newsp[i] = space;
       goto NEXT;
       }
     else
@@ -1844,8 +1847,8 @@ static void
 stemswaplevel(void)
 {
 int i, x;
-int *new = store_Xget((max_stave+1) * sizeof(int));
-for (i = 0; i <= max_stave; i++) new[i] = P_3L;
+int *new = store_Xget((MAX_STAVE+1) * sizeof(int));
+for (i = 0; i <= MAX_STAVE; i++) new[i] = P_3L;
 
 if (!read_expect_integer(&x, FALSE, TRUE)) return;
 
@@ -1865,7 +1868,7 @@ if (x > 0 && read_ch == '/')
     }
   }
 
-else for (i = 0; i <= max_stave; i++) new[i] = P_3L + x*2;
+else for (i = 0; i <= MAX_STAVE; i++) new[i] = P_3L + x*2;
 
 curmovt->stemswaplevel = new;
 }
@@ -1926,7 +1929,7 @@ n = font_search(s);
 if (n >= 0) font_table[fontid] = n; else
   {
   fontstr *fs;
-  if (font_count >= max_fonts) { error_moan(26, max_fonts); return; }
+  if (font_count >= MAX_FONTS) { error_moan(26, MAX_FONTS); return; }
   fs = &(font_List[font_count]);
   fs->psname = store_copystring(s);
   fs->widths = NULL;
@@ -1953,7 +1956,7 @@ static void
 textsizes(void)
 {
 int i;
-for (i = 0; i < MaxTextFont; i++)
+for (i = 0; i < MaxFontSizes; i++)
   {
   set_fontsize(oo(fontsizestr,fontsize_text) + i*sizeof(int), TRUE);
   if (read_ch == ',') next_ch();
@@ -2094,7 +2097,7 @@ static dirstr read_headlist[] = {
   { "endlinetieadjust", movt_intproc,   oo(movtstr,endlinetieadjust), int_f },
   { "endlinetiestyle",  movt_intproc,   oo(movtstr,endlinetiestyle), int_u },
   { "extenderlevel",    movt_intproc,   oo(movtstr,extenderlevel), int_f },
-  { "fbsize",           movt_fszproc,   oo(fontsizestr,fontsize_fbass), TRUE },
+  { "fbsize",           movt_fszproc,   oo(fontsizestr,fontsize_text)+ff_offset_fbass*sizeof(int), TRUE },
   { "footing",          movt_headproc,  oo(movtstr,footing), rh_footing },
   { "footnotesep",      movt_intproc,   oo(movtstr,footnotesep), int_f },
   { "footnotesize",     movt_fszproc,   oo(fontsizestr,fontsize_footnote), TRUE },
@@ -2153,7 +2156,7 @@ static dirstr read_headlist[] = {
   { "oldstemlength",    opt_boolproc,   glob_oldstemlength, TRUE },
   { "oldstretchrule",   oldstretchrule, 0, 0 },
   { "overlaydepth",     movt_intproc,   oo(movtstr,overlaydepth), int_f },
-  { "overlaysize",      movt_fszproc,   oo(fontsizestr,fontsize_olay), TRUE },
+  { "overlaysize",      movt_fszproc,   oo(fontsizestr,fontsize_text)+ff_offset_olay*sizeof(int), TRUE },
   { "page",             page,           0, 0 },
   { "pagefooting",      movt_headproc,  oo(movtstr,pagefooting), rh_pagefooting },
   { "pageheading",      movt_headproc,  oo(movtstr,pageheading), rh_pageheading },
@@ -2204,7 +2207,7 @@ static dirstr read_headlist[] = {
   { "thinbracket",      movt_listproc,  oo(movtstr,thinbracketlist), 0 },
   { "time",             timeproc,       0, 0 },
   { "timebase",         movt_cboolproc, oo(movtstr,showtimebase), TRUE },
-  { "timefont",         movt_fontproc,  oo(movtstr,font_time),oo(fontsizestr,fontsize_tsfont) },
+  { "timefont",         movt_fontproc,  oo(movtstr,font_time),oo(fontsizestr,fontsize_text)+ff_offset_ts*sizeof(int) },
   { "timewarn",         movt_cboolproc, oo(movtstr,timewarn), TRUE },
   { "topmargin",        movt_intproc,   oo(movtstr,topmargin), int_u+int_f },
   { "transpose",        transpose,      oo(movtstr,transpose), int_s },
@@ -2215,7 +2218,7 @@ static dirstr read_headlist[] = {
   { "tripletlinewidth", movt_intproc,   oo(movtstr,tripletlinewidth), int_u+int_f },
   { "underlaydepth",    movt_intproc,   oo(movtstr,underlaydepth), int_f },
   { "underlayextenders",movt_cboolproc, oo(movtstr,underlayextenders), TRUE },
-  { "underlaysize",     movt_fszproc,   oo(fontsizestr,fontsize_ulay), TRUE },
+  { "underlaysize",     movt_fszproc,   oo(fontsizestr,fontsize_text)+ff_offset_ulay*sizeof(int), TRUE },
   { "underlaystyle",    movt_intproc,   oo(movtstr,underlaystyle), int_u },
   { "unfinished",       movt_cboolproc, oo(movtstr,unfinished), TRUE },
   { "vertaccsize",      movt_fszproc,   oo(fontsizestr,fontsize_vertacc), FALSE }
