@@ -2,14 +2,14 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains part III of the code for reading in a PMW score file. It
-contains top-level code for reading in a bar. */
+contains top-level code for reading in one bar on one stave. */
 
 
 #include "pmwhdr.h"
@@ -38,11 +38,11 @@ is used for the input values, and baraccs_tp for the output values.
 Arguments:
   ba         the table that is to be set (baraccs or baraccs_tp)
   key        the key signature
-  
-Returns:     nothing  
+
+Returns:     nothing
 */
 
-void 
+void
 read_initbaraccs(uschar *ba, int key)
 {
 int i;
@@ -80,20 +80,20 @@ for (i = 0; i < baraccs_len; i += 12)
 *           Read up/down movement                *
 *************************************************/
 
-/* This is used for options for plets. On entry, read_ch should contain either 
-'u' or 'd', which may either be the first letter after / or might follow 'l' or 
-'r'. We don't come here for /lx and /rx, but they are mentioned in the error 
-message for unknown letters because they are something that could have been 
+/* This is used for options for plets. On entry, read_ch should contain either
+'u' or 'd', which may either be the first letter after / or might follow 'l' or
+'r'. We don't come here for /lx and /rx, but they are mentioned in the error
+message for unknown letters because they are something that could have been
 present.
 
 Arguments:
   value1      pointer to where the value read is added
   value2      if not NULL, the value is added here as well
-  
-Returns:      nothing  
+
+Returns:      nothing
 */
 
-static void 
+static void
 read_updown(int *value1, int *value2)
 {
 int sign, x;
@@ -104,12 +104,12 @@ switch(read_ch)
   default:
   error_moan(37, "/l<n>, /r<n>, /lx, /rx, /lu<n>, /ld<n>, /ru<n> or /rd<n>");
   next_ch();
-  return;  
-  } 
+  return;
+  }
 x = sign * read_movevalue();
 *value1 += x;
 if (value2 != NULL) *value2 += x;
-}     
+}
 
 
 /*************************************************
@@ -122,7 +122,7 @@ Arguments:   none
 Returns:     TRUE if not reached the end of the stave
 */
 
-BOOL 
+BOOL
 read_bar(void)
 {
 void *bardatastart;
@@ -145,6 +145,7 @@ stave_lastgracestem = 0;
 stave_lastwasdouble = stave_overbeam = FALSE;
 stave_firstinbar = TRUE;
 stave_hadnocount = FALSE;
+stave_tripletize = (stave_noteflags & nf_tripletize) != 0;
 stave_stemstackptr = stave_beamstackptr = 0;
 
 read_lastensuredtie = NULL;
@@ -171,21 +172,21 @@ if (!stave_notes)
   b_notesstr *p = store_getitem(b_notes);
   p->value = FALSE;
   }
-  
+
 /* If we are in an omitempty stave and the previous bar contained only an ibar
 or dbar item, or ended with an unusual barline style, we must insert a prevbar
 item here. */
 
 if (stavehead->omitempty &&
-    (read_prev_had_dbar || 
-     read_prev_had_ibar || 
+    (read_prev_had_dbar ||
+     read_prev_had_ibar ||
      read_prev_barlinestyle != stave_barlinestyle))
   {
   b_prevbarstr *p = store_getitem(b_prevbar);
-  p->dbar = read_prev_had_dbar;  
-  p->ibar = read_prev_had_ibar; 
-  p->style = read_prev_barlinestyle; 
-  } 
+  p->dbar = read_prev_had_dbar;
+  p->ibar = read_prev_had_ibar;
+  p->style = read_prev_barlinestyle;
+  }
 
 /* Remember where the real data starts for detecting an empty bar */
 
@@ -212,35 +213,35 @@ for (;;)
       if (read_ch == '|')
         {
         next_ch();
-        (void)store_getitem(b_ebar);  
+        (void)store_getitem(b_ebar);
         }
       else
-        {      
+        {
         (void)store_getitem(b_dbar);
         if (!curmovt->checkdoublebars) stave_checklength = FALSE;
         stave_lastwasdouble = TRUE;
-        } 
+        }
       }
     else if (read_ch == '?')          /* Invisible bar */
       {
       next_ch();
       (void)store_getitem(b_ibar);
       }
-    else if (isdigit(read_ch))        /* Specific bar line type */   
+    else if (isdigit(read_ch))        /* Specific bar line type */
       {
-      read_barlinestyle = read_integer(FALSE); 
-      }  
+      read_barlinestyle = read_integer(FALSE);
+      }
     if (read_ch == '=')               /* Continue beam over bar line */
       {
       next_ch();
       stave_overbeam = TRUE;
       }
-      
+
     /* Cancel the ensured space for a tied chord with seconds at the end of a
     bar. */
-    
-    if (read_lastensuredtie != NULL) read_lastensuredtie->value = 0; 
-       
+
+    if (read_lastensuredtie != NULL) read_lastensuredtie->value = 0;
+
     break;                            /* Exit the loop */
     }
 
@@ -278,33 +279,33 @@ for (;;)
 
         for (;;)
           {
-          accent *ap; 
+          accent *ap;
           sigch();
           if (read_ch == '\\') { next_ch(); break; }   /* End default */
-          
+
           /* Search the table of accents and ornaments */
-           
+
           for (ap = accent_chars; ap->string != NULL; ap++)
             {
-            int i; 
+            int i;
             int ln = (int)Ustrlen(ap->string);
             for (i = 0; i < ln; i++)
               if (read_chptr[i-1] != ap->string[i]) break;
             if (i >= ln)
               {
               read_chptr += ln - 1;
-              next_ch(); 
-              break; 
-              }  
+              next_ch();
+              break;
+              }
             }
 
           /* Found in the table */
-           
+
           if (ap->string != NULL)
             {
             if (ap->flag < 256) stave_ornament = ap->flag;
-              else stave_accentflags |= ap->flag;  
-            }  
+              else stave_accentflags |= ap->flag;
+            }
 
           /* Not found in the table */
 
@@ -322,9 +323,9 @@ for (;;)
 
           else { error_moan(45); next_sigch(); }
           }
-           
+
         if ((stave_accentflags & (af_staccato|af_staccatiss)) ==
-          (af_staccato|af_staccatiss)) error_moan(129);    
+          (af_staccato|af_staccatiss)) error_moan(129);
         }
 
       /* Deal with repeated bars; expect number > 0, but subtract one from it.
@@ -348,9 +349,9 @@ for (;;)
               b_nbarstr *p = store_getitem(b_nbar);
               p->x = p->y = 0;
               p->n = n;
-              p->s = NULL; 
+              p->s = NULL;
               p->ssize = 0;   /**** Not currently in use ****/
-                 
+
               sigch();
               while (read_ch == '/')
                {
@@ -362,44 +363,46 @@ for (;;)
                switch(read_ch)
                  {
                  case 'd':
-                 ysign = -1; 
+                 ysign = -1;
+                 /* Fall through */
 
                  case 'u':
                  next_ch();
                  read_expect_integer(&n, TRUE, FALSE);
                  p->y += n * ysign;
-                 break; 
-                 
+                 break;
+
                  case 'l':
-                 xsign = -1; 
-                 
+                 xsign = -1;
+                 /* Fall through */
+
                  case 'r':
                  next_ch();
                  read_expect_integer(&n, TRUE, FALSE);
                  p->x += n * xsign;
-                 break; 
-                 
+                 break;
+
                  /* One day we might want individual sizes for strings, but for
                  the moment this is not implemented. */
-                 
+
                  /*****************
-                 case 's': 
+                 case 's':
                  next_ch();
                  read_expect_integer(&n, FALSE, FALSE);
                  p->ssize = n;
-                 break;    
-                 *****************/ 
-                 
+                 break;
+                 *****************/
+
                  case '\"':
-                 p->s = string_read(); 
-                 break;  
-                 
+                 p->s = string_read();
+                 break;
+
                  default:
                  error_moan(10, "\"u\", \"d\", \"l\", \"r\", or quoted string");
-                 break; 
+                 break;
                  }
                }
-                
+
               read_stavedir[0] = 0;
               done = TRUE;
               }
@@ -446,53 +449,53 @@ for (;;)
     else
       {
       b_pletstr *p;
-      int sign; 
+      int sign;
       int  flags = 0;
       int  adjustx = 0;
       int  adjustyleft = stave_plety;
-      int  adjustyright = adjustyleft; 
+      int  adjustyright = adjustyleft;
 
       next_sigch();
-      
+
       /* The length of each note in the plet will be multiplied by
       stave_pletsupnum, and divided by stave_pletlen times stave_pletsupden. */
- 
+
       stave_pletsupnum = 0;   /* Indicates not explicitly set */
       stave_pletsupden = 1;   /* Normal case */
       stave_pletlen = 3;      /* Default to triplet */
-      
+
       /* Read an explicit specification */
- 
+
       if (isdigit(read_ch))
         {
         stave_pletlen = read_integer(FALSE);  /* First number */
-        
+
         /* A minus indicates that we are dividing a smaller number of notes
-        than the default. This is accomplished by dividing by 2. */ 
-        
+        than the default. This is accomplished by dividing by 2. */
+
         if (read_ch == '-') { next_sigch(); stave_pletsupden = 2; }
-        
+
         /* A slash indicates that the first number is really the number of
-        notes we are dividing, and the real value of stave_pletlen follows. */ 
-        
+        notes we are dividing, and the real value of stave_pletlen follows. */
+
         if (read_ch == '/' && isdigit(*read_chptr))
           {
-          stave_pletsupnum = stave_pletlen; 
+          stave_pletsupnum = stave_pletlen;
           next_ch();
-          stave_pletlen = read_integer(FALSE); 
-          }  
+          stave_pletlen = read_integer(FALSE);
+          }
         }
 
       /* If we are dividing into a power of two, assume we are dividing 3 into
       this number if a numerator was not provided; otherwise assume 2. */
-      
-      if (stave_pletsupnum == 0) stave_pletsupnum = 
+
+      if (stave_pletsupnum == 0) stave_pletsupnum =
         ((stave_pletlen & (-stave_pletlen)) == stave_pletlen)? 3 : 2;
-      
-      /* If the number of irregular notes is more than twice the number of 
-      regular notes, we double the numerator, because the irregulars must be 
-      the next note size down; similarly quadruple the numerator for even more 
-      notes. */ 
+
+      /* If the number of irregular notes is more than twice the number of
+      regular notes, we double the numerator, because the irregulars must be
+      the next note size down; similarly quadruple the numerator for even more
+      notes. */
 
       if (stave_pletlen >= 4*stave_pletsupnum) stave_pletsupnum *= 4;
         else if (stave_pletlen >= 2*stave_pletsupnum) stave_pletsupnum *= 2;
@@ -507,22 +510,22 @@ for (;;)
           case 'a':
           flags &= ~plet_b;
           flags |= plet_a | plet_by;
-          sign = +1; 
-          goto ABSPLET; 
+          sign = +1;
+          goto ABSPLET;
 
           case 'b':
           flags &= ~plet_a;
           flags |= plet_b | plet_by;
           sign = -1;
         ABSPLET:
-          flags &= ~(plet_abs | plet_bn); 
-          adjustyleft = adjustyright = 0; 
+          flags &= ~(plet_abs | plet_bn);
+          adjustyleft = adjustyright = 0;
           next_sigch();
           if (isdigit(read_ch))
             {
             flags |= plet_abs;
-            adjustyleft = adjustyright = sign * read_integer(TRUE);  
-            }   
+            adjustyleft = adjustyright = sign * read_integer(TRUE);
+            }
           break;
 
           case 'n':
@@ -532,12 +535,12 @@ for (;;)
           break;
 
           case 'x': flags |= plet_x; next_sigch(); break;
-          
+
           case 'u':
           case 'd':
           read_updown(&adjustyleft, &adjustyright);
           break;
-   
+
           case 'l':
           next_ch();
           if (isdigit(read_ch)) adjustx -= read_integer(TRUE); else
@@ -575,7 +578,7 @@ for (;;)
       p->flags = flags;
       p->x = adjustx;
       p->yleft = adjustyleft;
-      p->yright = adjustyright; 
+      p->yright = adjustyright;
       }
 
     /* Prevent reset (but resets are forbidden inside plets anyway). */
@@ -601,11 +604,11 @@ for (;;)
     case '<':
       {
       int flags = stave_hairpinflags;
-      int width = stave_hairpinwidth; 
+      int width = stave_hairpinwidth;
       int type = read_ch;
       int ending = (type == '<' && stave_hairpinbegun == '<') ||
                    (type == '>' && stave_hairpinbegun == '>');
-      int y = ending? 0 : stave_hairpiny; 
+      int y = ending? 0 : stave_hairpiny;
       int x = 0, h = 0;
       int slu = 0, sru = 0;
 
@@ -614,15 +617,15 @@ for (;;)
         {
         next_ch();
 
-        /* b is anomalous - /bar is always allowed, but /b only on 
+        /* b is anomalous - /bar is always allowed, but /b only on
         beginning hairpins. */
-          
+
         if (read_ch =='b' && *read_chptr == 'a' && read_chptr[1] == 'r')
-          { 
-          flags |= hp_bar; 
+          {
+          flags |= hp_bar;
+          next_ch();
           next_ch();
           next_ch();
-          next_ch();  
           }
 
         else switch(read_ch)
@@ -631,7 +634,7 @@ for (;;)
           case 'd': y -= read_movevalue(); break;
           case 'l': x -= read_movevalue(); break;
           case 'r': x += read_movevalue(); break;
-          
+
           case 'h':
           next_ch();
           h = 500;
@@ -661,48 +664,48 @@ for (;;)
             }
           else error_moan(37, "\"slu\", \"sld\", \"sru\" or \"srd\"");
           break;
-          
+
           default:
-          if (!ending) 
+          if (!ending)
             {
-            int sign; 
+            int sign;
             switch(read_ch)
               {
-              case 'a': 
-              flags &= ~hp_below; 
-              sign = 1; 
+              case 'a':
+              flags &= ~hp_below;
+              sign = 1;
               goto ABSHP;
-               
-              case 'b': 
-              flags |= hp_below; 
+
+              case 'b':
+              flags |= hp_below;
               sign = -1;
-            ABSHP: 
-              y = 0; 
+            ABSHP:
+              y = 0;
               flags &= ~(hp_middle | hp_abs);
-              next_ch(); 
+              next_ch();
               if (isdigit(read_ch))
                 {
                 flags |= hp_abs;
-                y = sign * read_integer(TRUE);  
-                }   
+                y = sign * read_integer(TRUE);
+                }
               break;
-   
-              case 'm': 
-              flags |= hp_below | hp_middle; 
-              next_ch(); 
+
+              case 'm':
+              flags |= hp_below | hp_middle;
+              next_ch();
               break;
-               
-              case 'w': 
-              next_ch(); 
-              read_expect_integer(&width, TRUE, FALSE); 
+
+              case 'w':
+              next_ch();
+              read_expect_integer(&width, TRUE, FALSE);
               break;
-               
+
               default:
               error_moan(37,
                 "\"u\", \"d\", \"l\", \"r\", \"a\", \"b\", \"m\", \"w\", \"slu\", \"sru\" or \"h\"");
               break;
               }
-            } 
+            }
           else error_moan(37, "\"u\", \"d\", \"l\", \"r\", \"su\" or \"h\"");
           break;
           }
@@ -732,7 +735,7 @@ for (;;)
         p->y = y;
         p->su = slu;
         p->h = h;
-        p->width = width; 
+        p->width = width;
         stave_hairpinsru = sru;
         stave_resetOK = FALSE;
         }
@@ -768,7 +771,7 @@ for (;;)
     else (void)store_getitem(b_dotbar);
     break;
 
-    /* A semi-colon used to be a general separator, way back in early days. 
+    /* A semi-colon used to be a general separator, way back in early days.
     Later, it was used as a beam breaking character, but still kept as a
     separator. This meant that if a beam break was incorrectly placed, no
     warning was given. It is therefore no longer a general separator, unless
@@ -776,19 +779,16 @@ for (;;)
     anyone will every feed PMW files with that set, but you never know). */
 
     case ';':
-    if (!opt_oldbeambreak)
-      error_moan(5, "Mis-placed semicolon (a beam break semicolon must "
-        "immediately follow a beamable note)"); 
-    next_sigch();   
+    if (!opt_oldbeambreak) error_moan(5, "semicolon");
+    next_sigch();
     break;
-    
-    /* Might as well give a similar error for a comma (which isn't old enough 
-    to be tied up with old beam breaks). */
-    
+
+    /* Might as well give a similar error for a stray comma (which isn't old
+    enough to be tied up with old beam breaks). */
+
     case ',':
-    error_moan(5, "Mis-placed comma (a beam break comma must "
-      "immediately follow a beamable note)"); 
-    next_sigch();   
+    error_moan(5, "comma");
+    next_sigch();
     break;
 
     /* A bracket can be the start of a repeat, or the start of a chord. We peek
@@ -820,46 +820,46 @@ created at the start of the next bar. */
 
 if (stavehead->omitempty)
   {
-  void *nextitem = store_nextitem(); 
+  void *nextitem = store_nextitem();
   bstr *p = bardatastart;
-  
+
   read_prev_had_ibar = FALSE;
-  read_prev_had_dbar = FALSE; 
-  read_prev_barlinestyle = stave_barlinestyle; 
-  
+  read_prev_had_dbar = FALSE;
+  read_prev_barlinestyle = stave_barlinestyle;
+
   while (p != nextitem)
     {
-    int type = p->type; 
+    int type = p->type;
     switch(type)
       {
       case b_Jump:
       p = (bstr *)(((b_Jumpstr *)p)->next);
       break;
-      
+
       case b_ibar:
       read_prev_had_ibar = TRUE;
       break;
-      
+
       case b_dbar:
       read_prev_had_dbar = TRUE;
       break;
-      
-      default:       
+
+      default:
       goto NORMALBAREND;
-      }  
+      }
     p = (bstr *)((uschar *)p + length_table[type]);
-    }   
- 
+    }
+
   /* If control gets here, 'twas only ibar or dbar */
-  
-  if (read_prev_had_ibar || 
-      read_prev_had_dbar || 
+
+  if (read_prev_had_ibar ||
+      read_prev_had_dbar ||
       read_barlinestyle != stave_barlinestyle)
     {
     read_prev_barlinestyle = read_barlinestyle;
     bardatastart = nextitem;             /* make empty */
-    }   
-  } 
+    }
+  }
 
 NORMALBAREND:
 
@@ -876,12 +876,12 @@ else
   {
   b_Endstr *b = store_getitem(b_End);
   b->overbeam = stave_overbeam;
-  b->barlinestyle = read_barlinestyle; 
-  
+  b->barlinestyle = read_barlinestyle;
+
   /* Set stave_maxbarlength to the longest length encountered, allowing for
   [reset]s. */
-  
-  if (stave_barlength > stave_maxbarlength) 
+
+  if (stave_barlength > stave_maxbarlength)
     stave_maxbarlength = stave_barlength;
 
   /* Check length. If the bar contains tuplets of prime numbers greater than
@@ -898,13 +898,63 @@ else
       format_movt = curmovt;
       error_moan(49, stave_barnumber, curstave,
         (extra > 0)? "long":"short", abs(extra));
-      }   
+      }
     }
 
   /* Deal with incomplete beams and unchosen stems */
 
   if (stave_beaming) read_setbeamstems();
   mac_setstackedstems(stave_laststemup? nf_stemup : 0);
+
+  /* If tripletizing was set at any point in this bar, scan it for dotted-
+  quaver groups and adjust the note lengths. Also handle dotted crotchet
+  followed by two semiquavers. */
+
+  if (stave_tripletize)
+    {
+    b_notestr *first = (b_notestr *)((stavehead->barindex)[stave_barnumber]);
+    if (first->type != b_note) first = misc_nextnote(first, NULL);
+
+    while (first != NULL)
+      {
+      b_notestr *next = misc_nextnote(first, NULL);
+      if (next == NULL) break;
+
+      /* Both notes must be flagged for tripletizing */
+
+      if ((first->flags & next->flags & nf_tripletize) != 0)
+        {
+        b_notestr *third;
+
+        if (first->length == (len_quaver * 3)/2 &&
+            next->length == len_squaver)
+          {
+          first->length = (len_crotchet * 2)/3;
+          next->length = len_crotchet/3;
+          first = misc_nextnote(next, NULL);
+          continue;
+          }
+
+        third = misc_nextnote(next, NULL);
+        if (third == NULL) break;
+        if ((third->flags & nf_tripletize) != 0 &&
+            first->length == (len_crotchet * 3)/2 &&
+            next->length == len_squaver &&
+            third->length == len_squaver)
+          {
+          first->length = (len_crotchet * 4)/3;
+          next->length = len_crotchet/3;
+          third->length = len_crotchet/3;
+          first = third;
+          continue;
+          }
+        }
+
+      /* No tripletizing this pair */
+
+      first = next;
+      }
+    }
   }
 
 /* Grumble if unclosed plet */
