@@ -2,20 +2,20 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains part IV of the code for reading in a PMW score file. It
-contains code for handling stave directives. The main function is at the 
+contains code for handling stave directives. The main function is at the
 bottom, preceded by a table of directives, which refer to the other functions.
-They all have the same interface: no arguments or results. The variable 
-read_dir is set to point to the found directive, and in its data structure 
+They all have the same interface: no arguments or results. The variable
+read_dir is set to point to the found directive, and in its data structure
 there may be up to two arguments. The action of each function is either to set
 up a new item and add it to the list (done by store_getitem()), and if
-necessary, fill in its data value(s), or to set flags or variables that affect 
+necessary, fill in its data value(s), or to set flags or variables that affect
 the way the stave's data is to be read. */
 
 
@@ -30,8 +30,8 @@ the way the stave's data is to be read. */
 
 static uschar real_clef[] = {
   clef_treble, clef_soprano, clef_mezzo, clef_alto, clef_tenor,
-  clef_cbaritone, clef_baritone, clef_bass, clef_deepbass, 
-  clef_treble, clef_treble, clef_treble, clef_treble, clef_treble, 
+  clef_cbaritone, clef_baritone, clef_bass, clef_deepbass,
+  clef_treble, clef_treble, clef_treble, clef_treble, clef_treble,
   clef_bass, clef_bass };
 
 static int clef_octave[] = {
@@ -45,7 +45,7 @@ static int read_assumeflag = FALSE;
 *        Common routine for dataless item        *
 *************************************************/
 
-static void 
+static void
 p_common(void)
 {
 (void)store_getitem(read_dir->arg1);
@@ -56,7 +56,7 @@ p_common(void)
 *         Common routine for above/below         *
 *************************************************/
 
-static void 
+static void
 p_above(void)
 {
 int flag = FALSE;
@@ -73,7 +73,7 @@ p->value = flag;
 *       Common routine for positive dimension    *
 *************************************************/
 
-static void 
+static void
 p_pvalue(void)
 {
 sigch();
@@ -90,7 +90,7 @@ else error_moan(10, "Number");
 *       Common routine for signed dimension      *
 *************************************************/
 
-static void 
+static void
 p_svalue(void)
 {
 int x;
@@ -105,7 +105,7 @@ p->value = x;
 *        Common routine for font setting         *
 *************************************************/
 
-static void 
+static void
 p_font(void)
 {
 int *p = (read_dir->arg1 == 0)? &stave_fbfont :
@@ -120,7 +120,7 @@ if (f >= 0) *p = f;
 *        Common routine for size setting         *
 *************************************************/
 
-static void 
+static void
 p_size(void)
 {
 int size;
@@ -128,8 +128,8 @@ int *p = (read_dir->arg1 == 0)? &stave_fbsize :
          (read_dir->arg1 == 1)? &stave_textsize :
          (read_dir->arg1 == 2)? &stave_ulsize : &stave_olsize;
 if (!read_expect_integer(&size, FALSE, FALSE)) return;
-if (--size < 0 || size >= MaxTextFont)
-  { error_moan(39, MaxTextFont); return; }
+if (--size < 0 || size >= MaxFontSizes)
+  { error_moan(39, MaxFontSizes); return; }
 *p = size;
 }
 
@@ -138,7 +138,7 @@ if (--size < 0 || size >= MaxTextFont)
 *     Common routine for fixed noteheads value   *
 *************************************************/
 
-static void 
+static void
 p_nh(void)
 {
 b_noteheadsstr *p = store_getitem(b_noteheads);
@@ -151,7 +151,7 @@ stave_stemflag = nf_stem;
 *             Beamacc and Beamrit                *
 *************************************************/
 
-static void 
+static void
 p_beamaccrit(void)
 {
 b_charvaluestr *p = store_getitem(read_dir->arg1);
@@ -170,7 +170,7 @@ p->value = stave_accritvalue;
 *               Clef setting                     *
 *************************************************/
 
-static void 
+static void
 p_clef(void)
 {
 if (!read_assumeflag)
@@ -193,7 +193,7 @@ if (isdigit(read_ch) || read_ch == '-')
   read_expect_integer(&stave_octave, FALSE, TRUE);
   stave_octave *= 12;
   }
-stave_lastbasenoteptr = NULL;   
+stave_lastbasenoteptr = NULL;
 }
 
 
@@ -202,12 +202,12 @@ stave_lastbasenoteptr = NULL;
 *************************************************/
 
 static const char *assume_list[] = {
-  "alto", "baritone", "bass", "contrabass", "deepbass", 
+  "alto", "baritone", "bass", "contrabass", "deepbass",
   "hclef", "key", "mezzo", "noclef", "soprabass", "soprano",
-  "tenor", "time", "treble", "trebledescant", "trebletenor", 
+  "tenor", "time", "treble", "trebledescant", "trebletenor",
   "trebletenorb" };
 
-static void 
+static void
 p_assume(void)
 {
 unsigned int i;
@@ -226,7 +226,7 @@ error_moan(10, "Clef, key, or time setting");
 *           Barlinestyle                        *
 ************************************************/
 
-static void 
+static void
 p_barlinestyle(void)
 {
 (void)read_expect_integer(&stave_barlinestyle, FALSE, FALSE);
@@ -235,7 +235,7 @@ read_barlinestyle = stave_barlinestyle;  /* For current bar */
 /* The default, for use with totally empty bars, is the first style given. This
 isn't entirely satisfactory, but copes with most cases. */
 
-if (stavehead->barlinestyle == 255) 
+if (stavehead->barlinestyle == 255)
   stavehead->barlinestyle = stave_barlinestyle;
 }
 
@@ -244,7 +244,7 @@ if (stavehead->barlinestyle == 255)
 *               Barnumber                        *
 *************************************************/
 
-static void 
+static void
 p_barnum(void)
 {
 b_barnumstr *p = store_getitem(b_barnum);
@@ -300,7 +300,7 @@ p->y = y;
 *                Couple                          *
 *************************************************/
 
-static void 
+static void
 p_couple(void)
 {
 uschar word[80];
@@ -316,7 +316,7 @@ else error_moan(10, "\"up\", \"down\", or \"off\"");
 *                 Cue                            *
 *************************************************/
 
-static void 
+static void
 p_cue(void)
 {
 stave_noteflags &= ~nf_cuedotalign;
@@ -325,11 +325,11 @@ sigch();
 if (read_ch == '/')
   {
   uschar word[80];
-  next_ch(); 
+  next_ch();
   read_word(word);
   if (Ustrcmp(word, "dotalign") == 0) stave_noteflags |= nf_cuedotalign;
-  else error_moan(10, "\"dotalign\"");   
-  } 
+  else error_moan(10, "\"dotalign\"");
+  }
 }
 
 
@@ -337,7 +337,7 @@ if (read_ch == '/')
 *                 Dots                           *
 *************************************************/
 
-static void 
+static void
 p_dots(void)
 {
 uschar word[80];
@@ -348,11 +348,22 @@ else error_moan(10, "\"above\" or \"below\"");
 }
 
 
+/*************************************************
+*              Doublenotes                       *
+*************************************************/
+
+static void
+p_doublenotes(void)
+{
+stave_notenum *= 2;
+}
+
+
 /*************************************************
 *                 Draw                           *
 *************************************************/
 
-static void 
+static void
 p_draw(void)
 {
 tree_node *node;
@@ -363,16 +374,16 @@ uschar word[80];
 sigch();
 while (isdigit(read_ch) || read_ch == '-' || read_ch == '+' || read_ch == '\"')
   {
-  if (read_ch == '\"') 
-    { 
+  if (read_ch == '\"')
+    {
     args[++argcount].d.ptr = read_draw_text();
-    args[argcount].dtype = dd_text; 
-    } 
-  else 
+    args[argcount].dtype = dd_text;
+    }
+  else
     {
     if (!read_expect_integer(&(args[++argcount].d.val), TRUE, TRUE)) break;
-    args[argcount].dtype = dd_number; 
-    } 
+    args[argcount].dtype = dd_number;
+    }
   sigch();
   }
 
@@ -387,7 +398,7 @@ if (node == NULL) error_moan(70, word); else
     {
     int i;
     d->args = store_Xget((argcount+1)*sizeof(drawitem));
-    d->args[0].dtype = dd_number; 
+    d->args[0].dtype = dd_number;
     d->args[0].d.val = argcount;
     for (i = 1; i <= argcount; i++) d->args[i] = args[i];
     }
@@ -399,7 +410,7 @@ if (node == NULL) error_moan(70, word); else
 *                 Endcue                         *
 *************************************************/
 
-static void 
+static void
 p_endcue(void)
 {
 stave_noteflags &= ~(nf_cuesize|nf_cuedotalign);
@@ -410,7 +421,7 @@ stave_noteflags &= ~(nf_cuesize|nf_cuedotalign);
 *             Endline & Endslur                  *
 *************************************************/
 
-static void 
+static void
 p_endline(void)
 {
 int id = 0;
@@ -446,7 +457,7 @@ else
 /* This sets the global read_endstave flag, which is detected in the
 stave-reading code. */
 
-static void 
+static void
 p_endstave(void)
 {
 read_endstave = TRUE;
@@ -457,7 +468,7 @@ read_endstave = TRUE;
 *              Footnote                          *
 *************************************************/
 
-static void 
+static void
 p_footnote(void)
 {
 b_footnotestr *f = store_getitem(b_footnote);
@@ -470,7 +481,7 @@ read_headfootingtext(&(f->h), rh_footnote);
 *                 Hairpins                       *
 *************************************************/
 
-static void 
+static void
 p_hairpins(void)
 {
 uschar word[80];
@@ -508,27 +519,40 @@ else if ((stave_hairpinflags & hp_middle) == 0 && isdigit(read_ch))
 *               Hairpinwidth                     *
 *************************************************/
 
-static void 
+static void
 p_hairpinwidth(void)
 {
 (void)read_expect_integer(&stave_hairpinwidth, TRUE, FALSE);
 }
 
 
+/*************************************************
+*              Halvenotes                        *
+*************************************************/
+
+static void
+p_halvenotes(void)
+{
+if (stave_notenum > 1) stave_notenum /= 2; else stave_noteden *= 2;
+}
+
+
+
 /*************************************************
 *                 Key                            *
 *************************************************/
 
-static void 
+static void
 p_key(void)
 {
 int warn = curmovt->keywarn;
 int oldkey = stave_key_tp;
+int oldwidth, newwidth;
+
 stave_key = read_key();
 read_initbaraccs(baraccs, stave_key);
 
 stave_key_tp = transpose_key(stave_key, stave_transpose, TRUE);
-
 read_initbaraccs(baraccs_tp, stave_key_tp);
 
 read_word(read_stavedir);
@@ -538,11 +562,22 @@ if (Ustrcmp(read_stavedir, "nowarn") == 0)
   warn = FALSE;
   }
 
+oldwidth = misc_keywidth(oldkey | 64, stave_clef);
+newwidth = misc_keywidth(stave_key_tp, stave_clef);
+
+/* If both the old (cancellation) width and the new key width are zero, there's 
+nothing we can do about warning. */
+
+if (oldwidth == 0 && newwidth == 0) warn = FALSE;
+
+/* If not "assume" create a new key item, preceded by a cancellation key item
+if the new signature is empty and the old one is not. */
+
 if (!read_assumeflag)
   {
   b_keystr *p = store_getitem(b_key);
 
-  if (stave_key_tp == 2 || stave_key_tp == 21)
+  if (newwidth == 0 && oldwidth != 0)
     {
     p->key = oldkey | 64;
     p->warn = warn;
@@ -554,6 +589,9 @@ if (!read_assumeflag)
   p->warn = warn;
   p->suppress = FALSE;
   }
+
+/* "Assume": insert a change of key without any printing. */
+
 else
   {
   b_setkeystr *p = store_getitem(b_setkey);
@@ -567,7 +605,7 @@ else
 *                 Justify                        *
 *************************************************/
 
-static void 
+static void
 p_justify(void)
 {
 uschar word[80];
@@ -604,7 +642,7 @@ else error_moan(10, "\"+\" or \"-\"");
 *             Linegap & Slurgap                  *
 *************************************************/
 
-static void 
+static void
 p_linegap(void)
 {
 b_linegapstr *p;
@@ -640,23 +678,23 @@ while (read_ch == '/')
       sigch();
       while (isdigit(read_ch) || read_ch == '-' || read_ch == '+' || read_ch == '\"')
         {
-        if (read_ch == '\"') 
+        if (read_ch == '\"')
           {
           args[++argcount].d.ptr = read_draw_text();
-          args[argcount].dtype = dd_text; 
-          } 
-        else 
+          args[argcount].dtype = dd_text;
+          }
+        else
           {
           if (!read_expect_integer(&(args[++argcount].d.val), TRUE, TRUE)) break;
-          args[argcount].dtype = dd_number; 
-          } 
+          args[argcount].dtype = dd_number;
+          }
         sigch();
         }
       if (argcount > 0)
         {
         int i;
         drawargs = store_Xget((argcount+1)*sizeof(drawitem));
-        drawargs[0].dtype = dd_number; 
+        drawargs[0].dtype = dd_number;
         drawargs[0].d.val = argcount;
         for (i = 1; i <= argcount; i++) drawargs[i] = args[i];
         }
@@ -694,14 +732,14 @@ while (read_ch == '/')
     if (!read_expect_integer(&x, TRUE, FALSE)) return;
     width = x;
     break;
-    
+
     case '\"':
-    gaptext = store_Xget(sizeof(gaptextstr)); 
+    gaptext = store_Xget(sizeof(gaptextstr));
     gaptext->text = string_check(string_read());
     gaptext->flags = 0;
     gaptext->size = 0;
     gaptext->x = 0;
-    gaptext->y = 0;  
+    gaptext->y = 0;
 
     while (read_ch == '/')
       {
@@ -719,23 +757,23 @@ while (read_ch == '/')
           }
         else error_moan(10, "/box, /ring, or /s");
         break;
-        
+
         case 'd':
         gaptext->y -= read_movevalue();
-        break;   
-    
+        break;
+
         case 'l':
         gaptext->x -= read_movevalue();
-        break;   
-    
+        break;
+
         case 's':
         next_ch();
         read_expect_integer(&size, FALSE, FALSE);
-        if (--size < 0 || size >= MaxTextFont)
-          { error_moan(39, MaxTextFont); size = 0; }
+        if (--size < 0 || size >= MaxFontSizes)
+          { error_moan(39, MaxFontSizes); size = 0; }
         gaptext->size = size;
         break;
-    
+
         case 'r':
         if (Ustrncmp(read_chptr, "ing", 3) == 0)
           {
@@ -746,18 +784,18 @@ while (read_ch == '/')
           gaptext->flags |= text_ring;
           }
         else gaptext->x += read_movevalue();
-        break;   
-    
+        break;
+
         case 'u':
         gaptext->y += read_movevalue();
-        break;   
+        break;
 
         default:
         error_moan(10, "/box, /ring, or /s");
         break;
         }
       }
-    break;  
+    break;
 
     default:
     error_moan(10, "=, l, r, or w");
@@ -767,7 +805,7 @@ while (read_ch == '/')
   sigch();
   }
 
-if (stave_slurcount <= 0) 
+if (stave_slurcount <= 0)
   error_moan(17, "%sgap directive", (read_dir->arg1)? "slur":"line");
 
 /* Width defaults to width of text or 4 points */
@@ -776,14 +814,14 @@ if (width < 0)
   {
   if (gaptext == NULL) width = 4000; else
     {
-    int fontsize = mac_muldiv((curmovt->stavesizes)[curstave], 
+    int fontsize = mac_muldiv((curmovt->stavesizes)[curstave],
       ((curmovt->fontsizes)->fontsize_text)[gaptext->size], 1000);
     int *matrix = ((curmovt->fontsizes)->fontmatrix_text)[gaptext->size];
     if (matrix != NULL) memcpy(font_transform, matrix, 4*sizeof(int));
     width = font_stringwidth(gaptext->text, font_rm, fontsize) + fontsize;
-    font_reset(); 
+    font_reset();
     }
-  }      
+  }
 
 /* Get data block and fill it in. */
 
@@ -805,7 +843,7 @@ p->gaptext = gaptext;
 *************************************************/
 
 /* These are all variations on the same theme. All of them create a play change
-item entry, with various different parameters. We start with a local subrouting 
+item entry, with various different parameters. We start with a local subrouting
 that they can all use.
 
 Arguments:
@@ -814,11 +852,11 @@ Arguments:
   note        note pitch
   volume      volumne
   transpose   transpose value
-  
-Returns:      nothing     
+
+Returns:      nothing
 */
 
-static void 
+static void
 makechange(int channel, int voice, int note, int volume, int transpose)
 {
 b_playchangestr *p = store_getitem(b_playchange);
@@ -836,7 +874,7 @@ read_lastplaychange = &(p->next);
 
 /*** Midichannel ***/
 
-static void 
+static void
 p_midichannel(void)
 {
 int channel;
@@ -844,9 +882,9 @@ int voicenumber;
 int volume = 128;
 uschar string[80];
 if (!read_expect_integer(&channel, FALSE, FALSE)) return;
-if (channel < 1 || channel > midi_maxchannel)
+if (channel < 1 || channel > MIDI_MAXCHANNEL)
   {
-  error_moan(109, midi_maxchannel);
+  error_moan(109, MIDI_MAXCHANNEL);
   return;
   }
 
@@ -869,7 +907,7 @@ if (read_plainstring(string))
     next_ch();
     if (read_expect_integer(&vol, FALSE, FALSE))
       {
-      if (vol > 15) 
+      if (vol > 15)
         error_moan(10, "Number between 0 and 15"); else volume = vol;
       }
     }
@@ -881,7 +919,7 @@ makechange(channel, voicenumber - 1, 128, volume, 0);  /* 128 => no change */
 
 /*** Midivoice ***/
 
-static void 
+static void
 p_midivoice(void)
 {
 int voicenumber;
@@ -905,7 +943,7 @@ else error_moan(10, "string");
 
 /*** Midipitch ***/
 
-static void 
+static void
 p_midipitch(void)
 {
 int note;
@@ -922,7 +960,7 @@ else error_moan(10, "string");
 
 /*** Playtranspose ***/
 
-static void 
+static void
 p_playtranspose(void)
 {
 int transpose;
@@ -932,7 +970,7 @@ makechange(128, 128, 128, 128, transpose);
 
 /*** Playvolume ***/
 
-static void 
+static void
 p_playvolume(void)
 {
 int volume;
@@ -954,7 +992,7 @@ makechange(128, 128, 128, volume, 0);
 *                Move & Rmove                    *
 *************************************************/
 
-static void 
+static void
 p_move(void)
 {
 int x;
@@ -983,7 +1021,7 @@ p->relative = read_dir->arg1;
 /* The stave magnification is used only if an explicit size is given; otherwise
 the fixed size is used. */
 
-static void 
+static void
 p_name(void)
 {
 sigch();
@@ -1053,8 +1091,8 @@ for (;;)
         next_ch();
         if (read_expect_integer(&size, FALSE, FALSE))
           {
-          if (--size < 0 || size >= MaxTextFont)
-            error_moan(39, MaxTextFont);
+          if (--size < 0 || size >= MaxFontSizes)
+            error_moan(39, MaxFontSizes);
           }
         else return;
         }
@@ -1088,21 +1126,21 @@ for (;;)
     read_ch = ' ';
     sigch();
 
-    while (isdigit(read_ch) || 
-           read_ch == '-'   || 
-           read_ch == '+'   || 
+    while (isdigit(read_ch) ||
+           read_ch == '-'   ||
+           read_ch == '+'   ||
            read_ch == '\"')
       {
-      if (read_ch == '\"') 
+      if (read_ch == '\"')
         {
         args[++argcount].d.ptr = read_draw_text();
-        args[argcount].dtype = dd_text; 
-        } 
-      else 
+        args[argcount].dtype = dd_text;
+        }
+      else
         {
         if (!read_expect_integer(&(args[++argcount].d.val), TRUE, TRUE)) break;
-        args[argcount].dtype = dd_number; 
-        } 
+        args[argcount].dtype = dd_number;
+        }
       sigch();
       }
 
@@ -1110,7 +1148,7 @@ for (;;)
       {
       int i;
       drawargs = store_Xget((argcount+1)*sizeof(drawitem));
-      drawargs[0].dtype = dd_number; 
+      drawargs[0].dtype = dd_number;
       drawargs[0].d.val = argcount;
       for (i = 1; i <= argcount; i++) drawargs[i] = args[i];
       }
@@ -1136,7 +1174,7 @@ for (;;)
 
 /* [newmovement] is unexpected here - give a tidy error message */
 
-static void 
+static void
 p_newmovement(void)
 {
 error_moan(73);  /* this stops processing */
@@ -1147,7 +1185,7 @@ error_moan(73);  /* this stops processing */
 *                 Nocheck                        *
 *************************************************/
 
-static void 
+static void
 p_nocheck(void)
 {
 stave_checklength = FALSE;
@@ -1162,7 +1200,7 @@ stave_checklength = FALSE;
 ignore if two nocounts in the same bar (causes big trouble and can happen if a
 bar line is accidentally omitted). */
 
-static void 
+static void
 p_nocount(void)
 {
 if (!stave_hadnocount)
@@ -1170,7 +1208,7 @@ if (!stave_hadnocount)
   if (++stave_totalnocount > (curmovt->barnovector)[stave_barnumber+1])
     (curmovt->barnovector)[stave_barnumber+1] = stave_totalnocount;
   stave_hadnocount = TRUE;
-  }    
+  }
 }
 
 
@@ -1178,7 +1216,7 @@ if (!stave_hadnocount)
 *                 Noteheads                      *
 *************************************************/
 
-static void 
+static void
 p_noteheads(void)
 {
 int nh;
@@ -1218,7 +1256,7 @@ p->value = nh;
 *                 Notes                          *
 *************************************************/
 
-static void 
+static void
 p_notes(void)
 {
 int flag = FALSE;
@@ -1237,7 +1275,7 @@ stave_notes = p->value = flag;
 
 /* There are three possible formats */
 
-static void 
+static void
 p_ns(void)
 {
 sigch();
@@ -1280,7 +1318,7 @@ else store_getitem(b_ens);     /* Reset */
 *                 Octave                         *
 *************************************************/
 
-static void 
+static void
 p_octave(void)
 {
 int x;
@@ -1294,7 +1332,7 @@ stave_lastbasenoteptr = NULL;
 *                Omitempty                       *
 *************************************************/
 
-static void 
+static void
 p_omitempty(void)
 {
 stavehead->omitempty = TRUE;
@@ -1305,7 +1343,7 @@ stavehead->omitempty = TRUE;
 *                  Page                          *
 *************************************************/
 
-static void 
+static void
 p_page(void)
 {
 b_pagestr *p = store_getitem(b_page);
@@ -1324,7 +1362,7 @@ read_expect_integer(&(p->value), FALSE, FALSE);
 *                Percussion                      *
 *************************************************/
 
-static void 
+static void
 p_percussion(void)
 {
 stavehead->stavelines = 128 + 1;    /* 128 => no clefs or keys */
@@ -1335,7 +1373,7 @@ stavehead->stavelines = 128 + 1;    /* 128 => no clefs or keys */
 *               Printpitch                       *
 *************************************************/
 
-static void 
+static void
 p_printpitch(void)
 {
 sigch();
@@ -1352,7 +1390,7 @@ else stave_printpitch = read_stavepitch();
 *                  Reset                         *
 *************************************************/
 
-static void 
+static void
 p_reset(void)
 {
 (void)store_getitem(b_reset);
@@ -1378,7 +1416,7 @@ stave_resetOK = FALSE;
 *                  Resume                        *
 *************************************************/
 
-static void 
+static void
 p_resume(void)
 {
 (void)store_getitem(b_resume);
@@ -1390,7 +1428,7 @@ stave_suspended = FALSE;
 *                Rlevel                          *
 *************************************************/
 
-static void 
+static void
 p_rlevel(void)
 {
 (void)read_expect_integer(&stave_restlevel, TRUE, TRUE);
@@ -1402,7 +1440,7 @@ if (opt_oldrestlevel) stave_restlevel *= 2;
 *              Rspace & Space                    *
 *************************************************/
 
-static void 
+static void
 p_rspace(void)
 {
 int x;
@@ -1418,7 +1456,7 @@ p->relative = read_dir->arg1;
 *                  Skip                          *
 *************************************************/
 
-static void 
+static void
 p_skip(void)
 {
 int x;
@@ -1428,12 +1466,12 @@ if (!read_expect_integer(&x, FALSE, FALSE)) return;
 
 if ((stavehead->barindex)[stave_barnumber] == store_nextitem())
   (stavehead->barindex)[stave_barnumber] = NULL;
-else 
+else
   {
   b_Endstr *b = store_getitem(b_End);
   b->overbeam = FALSE;
-  b->barlinestyle = stave_barlinestyle; 
-  } 
+  b->barlinestyle = stave_barlinestyle;
+  }
 
 /* Advance to the required bar */
 
@@ -1458,13 +1496,13 @@ backwards compatiblity, we retain the following synonyms:
   src = 2c
 
 A local subroutine is used to find the relevant slurmod on the chain, or to
-create a new one if it isn't found. 
+create a new one if it isn't found.
 
 Arguments:
   sequence     the sequence number
   anchor       points to the anchor of the chain
-  
-Returns:       pointer to the required slurmod  
+
+Returns:       pointer to the required slurmod
 */
 
 static b_slurmodstr *
@@ -1487,7 +1525,7 @@ return m;
 
 /*** Slur ***/
 
-static void 
+static void
 p_slur(void)
 {
 b_slurstr *p;
@@ -1601,7 +1639,7 @@ while (read_ch == '/')
       {
       mods->ly += x;
       mods->ry += x;
-      } 
+      }
     break;
 
     case 'd':
@@ -1611,7 +1649,7 @@ while (read_ch == '/')
       {
       mods->ly -= x;
       mods->ry -= x;
-      } 
+      }
     break;
 
     case 'e':
@@ -1621,7 +1659,7 @@ while (read_ch == '/')
 
     case 'l':
     case 'r':
-    if (mods == NULL) mods = findmods(0, &modchain); 
+    if (mods == NULL) mods = findmods(0, &modchain);
     a = (read_ch == 'l')? &(mods->ly) : &(mods->ry);
     b = (read_ch == 'l')? &(mods->lx) : &(mods->rx);
     next_ch();
@@ -1648,20 +1686,20 @@ while (read_ch == '/')
       int s = 0;
       int *z = NULL;
       b_slurmodstr *tempmods;
-       
-      if (read_ch == 'l') 
-        { 
-        tempmods = findmods(1, &modchain); 
+
+      if (read_ch == 'l')
+        {
+        tempmods = findmods(1, &modchain);
         a = &(tempmods->ry);
-        b = &(tempmods->c); 
+        b = &(tempmods->c);
         }
-      else 
-        { 
+      else
+        {
         tempmods = findmods(2, &modchain);
         a = &(tempmods->ly);
-        b = &(tempmods->c);   
+        b = &(tempmods->c);
         }
-         
+
       next_ch();
       if (read_ch == 'u' || read_ch == 'd')
         {
@@ -1700,10 +1738,10 @@ while (read_ch == '/')
     flags |= sflag_i;
     next_ch();
     if (read_ch == 'p')
-      {  
+      {
       flags |= sflag_idot;
       next_ch();
-      } 
+      }
     break;
 
     case 'o':
@@ -1740,7 +1778,7 @@ if ((flags & sflag_w) != 0)
   {
   if ((flags & sflag_l) != 0) error_moan(33, "lines");
   }
-  
+
 /* We don't support editorial marks on dotted or dashed slurs */
 
 /* ... but they have been requested, even though they may end up
@@ -1749,8 +1787,8 @@ drawing the editorial mark through a space ...
 if ((flags & sflag_e) != 0)
   {
   if ((flags & sflag_i) != 0) error_moan(94);
-  }   
-*/   
+  }
+*/
 
 /* Now output the slur proper, and count for nesting check. */
 
@@ -1767,7 +1805,7 @@ stave_slurcount++;
 *                  Smove                         *
 *************************************************/
 
-static void 
+static void
 p_smove(void)
 {
 b_movestr *p;
@@ -1783,7 +1821,7 @@ p->relative = stave_smove_relative = read_dir->arg1;
 *               Stavelines                       *
 *************************************************/
 
-static void 
+static void
 p_stavelines(void)
 {
 int n;
@@ -1797,10 +1835,10 @@ if (n > 6) error_moan(10, "Number in the range 0-6");
 *                Stavespacing                    *
 *************************************************/
 
-static void 
+static void
 p_ss(void)
 {
-unsigned int done[stave_bitvec_size];
+unsigned int done[STAVE_BITVEC_SIZE];
 
 sigch();
 mac_initstave(done, 0);
@@ -1824,16 +1862,16 @@ for (;;)
     if (!read_expect_integer(&spacing, TRUE, TRUE)) return;
     }
 
-  if (stave > max_stave) error_moan(42, max_stave); else
+  if (stave > MAX_STAVE) error_moan(42, MAX_STAVE); else
     {
     b_ssstr *p = store_getitem(read_dir->arg1);
     p->opt = opt;
     p->stave = stave;
     p->value = spacing;
     }
-    
+
   if (mac_teststave(done, stave)) error_moan(106, stave, read_dir->name);
-  mac_setstave(done, stave); 
+  mac_setstave(done, stave);
   sigch();
   if (read_ch == ',') next_sigch();
   if (read_ch != '+' && read_ch != '-' && !isdigit(read_ch)) break;
@@ -1845,7 +1883,7 @@ for (;;)
 *                 Stems/Ties                     *
 *************************************************/
 
-static void 
+static void
 p_stems(void)
 {
 int *p = (read_dir->arg1 == 1)? &stave_stemforce : &stave_ties;
@@ -1862,7 +1900,7 @@ else error_moan(10, "\"auto\", \"above\", \"up\", \"below\", or \"down\"");
 *               Stemlength = Sl                  *
 *************************************************/
 
-static void 
+static void
 p_stemlength(void)
 {
 (void)read_expect_integer(&stave_stemlength, TRUE, TRUE);
@@ -1874,7 +1912,7 @@ if (opt_oldstemlength) stave_stemlength *= 2;
 *                  Suspend                       *
 *************************************************/
 
-static void 
+static void
 p_suspend(void)
 {
 (void)store_getitem(b_suspend);
@@ -1886,7 +1924,7 @@ stave_suspended = TRUE;
 *                Systemgap                       *
 *************************************************/
 
-static void 
+static void
 p_sg(void)
 {
 b_sgstr *p;
@@ -1906,7 +1944,7 @@ p->value = value;
 *                  Text                          *
 *************************************************/
 
-static void 
+static void
 p_text(void)
 {
 int sign = 1;
@@ -1948,7 +1986,7 @@ else
 *                 Time                           *
 *************************************************/
 
-static void 
+static void
 p_time(void)
 {
 int warn = curmovt->timewarn;
@@ -2014,7 +2052,7 @@ else
 a facility, not a bug! However, we must call the routine in order to set up the
 letter count for transposing notes. The yield is discarded. */
 
-static void 
+static void
 p_transpose(void)
 {
 int x;
@@ -2030,7 +2068,7 @@ stave_lastbasenoteptr = NULL;
 *                Transposedacc                   *
 *************************************************/
 
-static void 
+static void
 p_transposedacc(void)
 {
 uschar word[80];
@@ -2045,7 +2083,7 @@ if (Ustrcmp(word, "force") == 0) stave_transposedaccforce = TRUE;
 *                 Tremolo                        *
 *************************************************/
 
-static void 
+static void
 p_tremolo(void)
 {
 b_tremolostr *p;
@@ -2073,11 +2111,33 @@ p->join = join;
 }
 
 
+/*************************************************
+*               Tripletize                       *
+*************************************************/
+
+static void
+p_tripletize(void)
+{
+read_word(read_stavedir);
+if (Ustrcmp(read_stavedir, "off") == 0)
+  {
+  read_stavedir[0] = 0;
+  stave_noteflags &= ~nf_tripletize;
+  }
+else
+  {
+  stave_noteflags |= nf_tripletize;
+  stave_tripletize = TRUE;   /* Check bar for tripletizing */
+  }
+if (Ustrcmp(read_stavedir, "on") == 0) read_stavedir[0] = 0;
+}
+
+
 /*************************************************
 *               Triplets                         *
 *************************************************/
 
-static void 
+static void
 p_triplets(void)
 {
 int hadone = FALSE;
@@ -2147,11 +2207,11 @@ p->value = flag;
 /* Knows that ulevelstr has the same form as olevelstr; the actual type
 required is in the argument. */
 
-static void 
+static void
 p_uolevel(void)
 {
 b_ulevelstr *p;
-int autoflag; 
+int autoflag;
 int value = 0;
 
 sigch();
@@ -2200,6 +2260,7 @@ static dirstr read_stavedirlist[] = {
   { "cue",           p_cue,        0, TRUE },
   { "deepbass",      p_clef,       clef_deepbass, FALSE },
   { "dots",          p_dots,       0, TRUE },
+  { "doublenotes",   p_doublenotes,0, TRUE },
   { "draw",          p_draw,       FALSE, FALSE },
   { "el",            p_endline,    0, TRUE },
   { "endcue",        p_endcue,     0, TRUE },
@@ -2215,6 +2276,7 @@ static dirstr read_stavedirlist[] = {
   { "h",             p_nh,         nh_harmonic, TRUE },
   { "hairpins",      p_hairpins,   0, TRUE },
   { "hairpinwidth",  p_hairpinwidth, 0, TRUE },
+  { "halvenotes",    p_halvenotes, 0, TRUE },
   { "hclef",         p_clef,       clef_h, FALSE },
   { "justify",       p_justify,    0, TRUE },
   { "key",           p_key,        0, FALSE },
@@ -2269,6 +2331,7 @@ static dirstr read_stavedirlist[] = {
   { "space",         p_rspace,     FALSE, FALSE },
   { "sshere",        p_ss,         b_sshere, TRUE },
   { "ssnext",        p_ss,         b_ssnext, TRUE },
+  { "stafflines",    p_stavelines, 0, TRUE },
   { "stavelines",    p_stavelines, 0, TRUE },
   { "stemlength",    p_stemlength, 0, TRUE},
   { "stems",         p_stems,      1, TRUE },
@@ -2288,6 +2351,7 @@ static dirstr read_stavedirlist[] = {
   { "trebletenor",   p_clef,       clef_trebletenor, FALSE },
   { "trebletenorb",  p_clef,       clef_trebletenorB, FALSE },
   { "tremolo",       p_tremolo,    0, TRUE },
+  { "tripletize",    p_tripletize, 0, TRUE },
   { "triplets",      p_triplets,   0, TRUE },
   { "ulevel",        p_uolevel,    b_ulevel, TRUE },
   { "ulhere",        p_svalue,     b_ulhere, TRUE },
@@ -2308,14 +2372,14 @@ static int read_stavedirsize = sizeof(read_stavedirlist)/sizeof(dirstr);
 *************************************************/
 
 /* The directive name is already in read_stavedir. If processing
-this one reads one word ahead, leave that word in read_stavedir
-for next time. 
+this one reads one word ahead, it leaves that word in read_stavedir
+for next time.
 
 Arguments:  none
 Returns:    nothing
 */
 
-void 
+void
 read_stavedirective(void)
 {
 dirstr *first = read_stavedirlist;
@@ -2345,7 +2409,7 @@ read_stavedir[0] = 0;
 *            Read a clef name                    *
 *************************************************/
 
-/* This function is used by the printkey heading directive. It is here so that 
+/* This function is used by the printkey heading directive. It is here so that
 it can use the table above for the supported clefs, thus avoiding a duplicate
 list.
 
@@ -2372,13 +2436,13 @@ while (last > first)
   if (c == 0)
     {
     if (d->proc == p_clef) return d-> arg1;
-    break; 
+    break;
     }
   if (c > 0) first = d + 1; else last = d;
   }
-  
+
 error_moan(126, word);
-return 0; 
+return 0;
 }
 
 /* End of read4.c */
