@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains part V of the code for reading in a PMW score file - code
@@ -54,7 +54,7 @@ static int sbra_left[] = { 5800, 6800, 6300, 6300, 6800, 6800 };
 static int maxpitch, minpitch, chordcount;
 static int notetype, length, stemforce;
 static BOOL seconds;
-static tiedata this_tiedata[max_chordsize];
+static tiedata this_tiedata[MAX_CHORDSIZE];
 
 /* This variable is set true when the only notes in a bar so far are notated
 using "p" and "x" and are tied to their predecessors. It is used to determine
@@ -523,44 +523,60 @@ else
   }
 
 /* If a relevant note is followed by a comma, set for a secondary beam break.
-If followed by a semicolon, set for a primary beam break.
+If followed by a semicolon, set for a primary beam break. We used to give an
+error when either of these characters did not follow a quaver or shorter note.
+This makes it annoying to use doublenotes or halvenotes to set a piece in
+different ways. We now allow comma and semicolon after any note at this
+point, only generating the relevant break for short enough notes. Any other
+occurrences still give an error.
 
 COMPATIBILITY FEATURE: For compatibility with the original program, if the
-"oldbeambreaks" option is set, use space or ! for a primary break, and
-semicolon for no break at all. */
+"oldbeambreak" option is set, use space or ! for a primary break. Semicolon
+will be treated (elsewhere) as a general separator and ignored. */
 
-if (notetype >= quaver)
+if (opt_oldbeambreak)
   {
-  if (read_ch == ',')
+  if (read_ch == ' ' || read_ch == '!')
     {
-    b_beambreak2str *b = store_getitem(b_beambreak2);
+    next_ch();
+    if (notetype >= quaver)
+      {
+      (void)store_getitem(b_beambreak);
+      if (stave_beaming) read_setbeamstems();
+      }
+    }
+  else if (read_ch == ',') goto SECBEAMBREAK;   
+  }
+
+else  /* Not oldbeambreak */
+  {
+  if (read_ch == ';')
+    {
+    next_ch();
+    if (notetype >= quaver)
+      {
+      (void)store_getitem(b_beambreak);
+      if (stave_beaming) read_setbeamstems();
+      }
+    }
+  else if (read_ch == ',')
+    {
+    unsigned int v;
+    SECBEAMBREAK: 
     next_ch();
     if (isdigit(read_ch))
       {
-      b->value = read_ch - '0';
+      v = read_ch - '0';
       next_ch();
       }
-    else b->value = 1;
-    }
-  else if (!opt_oldbeambreak)
-    {
-    if (read_ch == ';')
+    else v = 1;
+    if (notetype >= quaver)
       {
-      next_ch();
-      (void)store_getitem(b_beambreak);
-      if (stave_beaming) read_setbeamstems();
+      b_beambreak2str *b = store_getitem(b_beambreak2);
+      b->value = v;
       }
     }
-  else
-    {
-    if (read_ch == ' ' || read_ch == '!')
-      {
-      next_ch();
-      (void)store_getitem(b_beambreak);
-      if (stave_beaming) read_setbeamstems();
-      }
-    }
-  }
+  }   
 
 /* If we encountered '}' previously or here, end plet group */
 
@@ -634,7 +650,6 @@ int chordlength = 0;
 stave_firstnoteptr = NULL;
 maxpitch = 0;
 minpitch = 256;
-chordcount = 0;
 stemforce = 0;                      /* stem not forced */
 seconds = FALSE;
 
@@ -662,6 +677,7 @@ if (read_ch == 'x')
     b_notestr *new;
     bstr *p = (bstr *)last_note_ornament;
     do_underlay();
+    chordcount = 0; 
 
     if (p != NULL) while (p != (bstr *)old)
       {
@@ -702,6 +718,11 @@ if (read_ch == 'x')
     stave_pitchtotal += new->truepitch;
     stave_pitchcount++;
     chordcount++;
+    
+    /* This error should never occur because the original chord should be
+    diagnosed. Paranoia. */ 
+ 
+    if (chordcount >= MAX_CHORDSIZE) error_moan(132, MAX_CHORDSIZE); /* Hard */
     if (new->spitch > maxpitch) maxpitch = new->spitch;
     if (new->spitch < minpitch) minpitch = new->spitch;
 
@@ -756,6 +777,7 @@ if (read_ch == '(') { inchord = nf_chord; next_sigch(); }
 
 /* Loop to read all the notes of a chord */
 
+chordcount = 0;
 for (;;)
   {
   b_notestr *noteptr;
@@ -1014,6 +1036,7 @@ for (;;)
     which may have been in the previous bar. Save the information in case this
     note is tied. */
 
+    if (chordcount >= MAX_CHORDSIZE) error_moan(132, MAX_CHORDSIZE); /* Hard */
     this_tiedata[chordcount].pitch = pitch;
 
     if (acc)
@@ -1222,11 +1245,11 @@ TRANSPOSE:
   /* Handle doubled or halved note lengths - note that full bar rests must be
   skipped (the centre flag is an indicator). */
 
-  if ((main_notenum != 1 || main_noteden != 1) && (flags & nf_centre) == 0)
+  if ((stave_notenum != 1 || stave_noteden != 1) && (flags & nf_centre) == 0)
     {
-    int i = main_notenum;
+    int i = stave_notenum;
     while (i > 1) { length += length; notetype--; i /= 2; }
-    i = main_noteden;
+    i = stave_noteden;
     while (i > 1) { length /= 2; notetype++; i /= 2; }
     }
 
