@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2012 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: March 2012 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains code for outputting one bar */
@@ -224,7 +224,7 @@ for (out_stave = out_laststave; out_stave >= 0; out_stave--)
     main_bit[out_stave & 0x1f];
 
   if (!another)
-    for (i = (out_stave >> 5) + 1; i < stave_bitvec_size; i++)
+    for (i = (out_stave >> 5) + 1; i < STAVE_BITVEC_SIZE; i++)
       if (notsuspend[i] != 0) { another = TRUE; break; }
 
   if (another && out_sysblock->stavespacing[out_stave] > 0)
@@ -506,8 +506,8 @@ for (out_stave = out_laststave; out_stave >= 0; out_stave--)
 
       int fontsize = mac_muldiv(main_stavemagn,
         overlay?
-          (curmovt->fontsizes)->fontsize_olay :
-          (curmovt->fontsizes)->fontsize_ulay,
+          ((curmovt->fontsizes)->fontsize_text)[ff_offset_olay] :
+          ((curmovt->fontsizes)->fontsize_text)[ff_offset_ulay],
         1000);
 
       if (xx == 0)  /* A complete system of hyphens or extender */
