@@ -464,7 +464,7 @@ int thisnotetype = longestnote + 1;
 int sladjust = mac_muldiv(75*main_stavemagn, n_fontsize, 1000000) + n_cueadjust;
 int sradjust = mac_muldiv(115*main_stavemagn, n_fontsize, 1000000) + n_cueadjust;
 
-uschar taildirflags[max_beamsize];
+uschar taildirflags[MAX_BEAMSIZE];
 
 /* Add possible cue note adjustment into endpoints */
 
