@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains code for supporting the "draw" directives in PMW. It
@@ -162,8 +162,8 @@ static BOOL currentpoint;
 static int gray;
 static int level;
 static int xp, yp, cp;
-static drawitem draw_variables[max_draw_variable + 1];
-static drawitem draw_stack[draw_stacksize];
+static drawitem draw_variables[MAX_DRAW_VARIABLE + 1];
+static drawitem draw_stack[DRAW_STACKSIZE];
 
 
 
@@ -398,8 +398,8 @@ while (read_ch == '/')
     next_ch();
     if (read_expect_integer(&size, FALSE, FALSE))
       { 
-      if (--size < 0 || size >= MaxTextFont) 
-        { error_moan(39, MaxTextFont); size = 0; }
+      if (--size < 0 || size >= MaxFontSizes) 
+        { error_moan(39, MaxFontSizes); size = 0; }
       textptr->size = size;
       } 
     break;
@@ -469,10 +469,10 @@ read_word(word);
 if (word[0] == 0) { error_moan(10, "name"); return; }
 
 drawnode->name = store_copystring(word);
-drawnode->data = store_Xget(draw_blocksize);
+drawnode->data = store_Xget(DRAW_BLOCKSIZE);
 
 ptr = (drawitem *)drawnode->data;
-left = draw_blocksize/sizeof(drawitem);
+left = DRAW_BLOCKSIZE/sizeof(drawitem);
 
 /* Loop to read the contents of the draw function */
 
@@ -523,9 +523,9 @@ for (;;)
       node = Tree_Search(draw_variable_tree, word);
       if (node == NULL)
         {
-        if (draw_nextvariable > max_draw_variable)
+        if (draw_nextvariable > MAX_DRAW_VARIABLE)
           {
-          error_moan(100, max_draw_variable + 1);
+          error_moan(100, MAX_DRAW_VARIABLE + 1);
           draw_nextvariable--;
           }
         value = draw_nextvariable++;
@@ -603,9 +603,9 @@ for (;;)
   if (left < 4)
     {
     (ptr++)->d.val = dr_jump;
-    ptr->d.ptr = store_Xget(draw_blocksize);
+    ptr->d.ptr = store_Xget(DRAW_BLOCKSIZE);
     ptr = (drawitem *)(ptr->d.ptr);
-    left = draw_blocksize/sizeof(drawitem);
+    left = DRAW_BLOCKSIZE/sizeof(drawitem);
     }
 
   /* Add this item to the "program". Numbers, variable names, and variable 
@@ -887,7 +887,7 @@ if (level > 20) draw_error(84, " ", t);
 while (p->d.val != dr_end)
   {
   int errornumber = 0;
-  if (out_drawstackptr > draw_stacksize - 4) 
+  if (out_drawstackptr > DRAW_STACKSIZE - 4) 
     errornumber = 121;
   else
     {
@@ -1080,7 +1080,7 @@ while (p->d.val != dr_end)
     case dr_def:
       {
       int n = draw_stack[out_drawstackptr-2].d.val;
-      if (n < 0 || n > max_draw_variable) draw_error(101, "", t);
+      if (n < 0 || n > MAX_DRAW_VARIABLE) draw_error(101, "", t);
         else draw_variables[n] = draw_stack[out_drawstackptr-1];
       }
     out_drawstackptr -= 2;
