@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains the main code typesetting one note or chord */
@@ -310,7 +310,7 @@ else
       /* Move back to the key signature if no left repeat, else add width of 
          repeat */  
       leftx = (out_findTentry(posx_RLleft) == NULL)? 
-        out_barx - page_leftbarspace : out_barx + 6 * main_stavemagn;
+        out_barx - PAGE_LEFTBARSPACE : out_barx + 6 * main_stavemagn;
       }  
     else leftx = out_lastbarlinex;
 
