@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2010 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: December 2010 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains code for outputting non-note items in a bar */
@@ -391,8 +391,9 @@ switch (p->type)
       bstr *pp = ((curmovt->stavetable)[out_stave])->barindex[out_bar+1];
       if (pp != NULL)
         {
-        while (pp->type == b_Jump)
-          pp = (bstr *)(((b_Jumpstr *)pp)->next);
+       while (pp->type == b_Jump)
+          pp = (bstr *)
+            ((uschar *)(((b_Jumpstr *)pp)->next) + length_table[b_Jump]);
         if (pp->type == b_lrepeat)
           {
           reptype = rep_dright;
@@ -411,7 +412,8 @@ switch (p->type)
     {
     bstr *pp = (bstr *)((uschar *)p + length_table[p->type]);
     while (pp->type == b_Jump)
-      pp = (bstr *)(((b_Jumpstr *)pp)->next);
+       pp = (bstr *)
+         ((uschar *)(((b_Jumpstr *)pp)->next) + length_table[b_Jump]);
     out_writerepeat(out_barx +
       out_findXoffset(out_moff + posx_RR) + out_Xadjustment,
         (pp->type == b_lrepeat)? rep_dright : rep_right, magn);
@@ -473,7 +475,7 @@ switch (p->type)
     {
     b_dynmovestr *d = (b_dynmovestr *)p;
     int z = d->dynamic;
-    out_dynmovef[z] = d->bflags; 
+    out_dynmovef[z] = d->bflags;
     out_dynmovex[z] = d->x;
     out_dynmovey[z] = mac_muldiv(d->y, main_stavemagn, 1000);
     }
@@ -484,18 +486,18 @@ switch (p->type)
   case b_comma:
     {
     int y;
-    uschar *s; 
+    uschar *s;
     b_notestr *pp = misc_nextnote((b_notestr *)p, 0);
     if (main_righttoleft)
       {
       y = 19;
-      s = US"\xc3\x81";  
+      s = US"\xc3\x81";
       }
     else
       {
       y = 22;
-      s = US"N";  
-      }       
+      s = US"N";
+      }
     if (pp != NULL && pp->spitch > 148) y += pp->spitch - 148;
     out_string(s, font_mf, 10*main_stavemagn,
       out_barx + out_findXoffset(out_moff + posx_comma) + out_Xadjustment,
@@ -614,6 +616,8 @@ switch (p->type)
     }
   else
     {
+    if (out_textqueueptr >= TEXT_QUEUE_SIZE)
+      error_moan(131, TEXT_QUEUE_SIZE);
     out_textXqueue[out_textqueueptr] = out_textX;
     out_textqueue[out_textqueueptr++] = (b_textstr *)p;
     }
