@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2008 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: September 2008 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains code for outputting text items */
@@ -36,7 +36,7 @@ Returns:      nothing
 void
 out_extension(int x0, int x1, int y, int fontsize)
 {
-int i, xx0;
+int i;
 int uwidth = font_stringwidth(US"_", font_rm, fontsize);
 int length = x1 - x0;
 int count, remain;
@@ -52,7 +52,7 @@ if (count <= 0)
   }
 
 y = out_ystave - ((y + curmovt->extenderlevel) * main_stavemagn)/1000;
-xx0 = x0 += main_stavemagn;
+x0 += main_stavemagn;
 
 for (i = 0; i < count; i++) s[i] = '_';
 s[count] = 0;
@@ -536,7 +536,7 @@ if ((flags & text_ul) != 0)
 
   if (*pp == '=' || *pp == '-')
     {
-    ulaystr *u = store_Xget(sizeof(ulaystr));
+    u = store_Xget(sizeof(ulaystr));
     u->next = bar_cont->ulay;
     bar_cont->ulay = u;
 
@@ -586,12 +586,12 @@ else
 
     else
       {
-      posstr *p = out_postable;
-      while (p < out_poslast)       /* Just for safety */
+      posstr *pt = out_postable;
+      while (pt < out_poslast)       /* Just for safety */
         {
-        if (p->moff >= posx_timefirst)
-          { x =  out_barx + p->xoff; break; }
-        p++;
+        if (pt->moff >= posx_timefirst)
+          { x =  out_barx + pt->xoff; break; }
+        pt++;
         }
       }
     }
