@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains the code for generating an image of one individual note
@@ -668,39 +668,39 @@ else if (curmovt->codemultirests && out_manyrest < 9)
   {
   ps_musstring(multireststrings[out_manyrest - 2], fontsize, x, y - 2000);
   }
-  
+
 /* Output a |----| long rest sign. If the bar is unusually long or unusually
 short, draw the long rest symbol; note that ps_line() works in conventional
-coordinates relative to the base line of the stave. The variable n_longrestmid 
+coordinates relative to the base line of the stave. The variable n_longrestmid
 contains the mid-point of the long rest. */
-  
+
 else
   {
-  int wide; 
+  int wide;
   int rs = out_barlinex - n_longrestmid;
-    
+
   if ((wide = rs > 40*main_stavemagn) || x - out_barx < 6000)
     {
     posstr *p;
     int xl, xr;
     int vthick = (3*main_stavemagn)/10;
-    int hthick = 3*main_stavemagn;  
+    int hthick = 3*main_stavemagn;
     int adjust = 0;
-    int min = wide? 15000 : 12000; 
-    
-    /* Calculate an adjustment for anything at the end of the bar, e.g. a clef 
+    int min = wide? 15000 : 12000;
+
+    /* Calculate an adjustment for anything at the end of the bar, e.g. a clef
     change. */
-    
+
     for (p = out_posptr + 1; p->moff <= 0; p++); /* Skip preceding */
     for (; p < out_poslast; p++)
       adjust += p[1].xoff - p->xoff;
 
-    /* Place the right hand end with respect to the the barline, nearer for a 
+    /* Place the right hand end with respect to the the barline, nearer for a
     narrow bar, then place the left hand end symmetrically. */
 
     if (adjust < min) adjust = min + adjust/3;
       else adjust += 5000;
-    
+
     xr = out_barlinex - mac_muldiv(adjust, main_stavemagn, 1000);
     xl = 2*n_longrestmid - xr;
 
@@ -708,11 +708,11 @@ else
     ps_line(xl, 4*main_stavemagn, xl, 12*main_stavemagn, vthick, 0);
     ps_line(xr, 4*main_stavemagn, xr, 12*main_stavemagn, vthick, 0);
     }
-  
+
   /* Use the long rest character */
-  
+
   else ps_muschar(x, y, mc_longrest, fontsize);
-  } 
+  }
 }
 
 
@@ -1007,7 +1007,12 @@ if ((n_acflags & af_dynoutside) != 0)
   int i;
   int yextra = 0;
   int upflag = acc_upflag;
-  int f = n_acflags << 3;        /* first bit to top position */
+
+  /* Sanitizing compilers may complain about shifting negative numbers and/or
+  shifting top bits off words, so be pedantic here. Start by getting the first
+  relevant bit to the top position. */
+
+  unsigned int f = (unsigned int)(n_acflags & 0x1fffffff) << 3;
 
   /* The order is: > v V ' down up. We assume that only one of the first four
   will exist, possibly with one of the last two. */
@@ -1043,7 +1048,7 @@ if ((n_acflags & af_dynoutside) != 0)
 
     /* Print the accent if its bit is set. */
 
-    if (f < 0)
+    if ((f & 0x80000000) != 0)
       {
       int d = dyn_list[i]; /* standard accent number */
       int y;
@@ -1071,7 +1076,7 @@ if ((n_acflags & af_dynoutside) != 0)
       out_dynmovex[d] = out_dynmovey[d] = out_dynmovef[d] = 0;
       }
 
-    f = f << 1;
+    f = (f & 0x7fffffff) << 1;
     }
   }
 
@@ -1129,6 +1134,7 @@ if (n_ornament != NULL)
 
       case or_trnat:
       *p++ = '(';
+      /* Fall through */
 
       case or_tr:
       TR:
@@ -1220,9 +1226,11 @@ if (n_ornament != NULL)
 
       case or_trem3:
       *p++ = 146;
+      /* Fall through */
 
       case or_trem2:
       *p++ = 146;
+      /* Fall through */
 
       case or_trem1:
       *p++ = 146;
