@@ -2,10 +2,10 @@
 *    The PMS Music Typesetter - 2nd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains code for reading and processing strings. */
@@ -1137,8 +1137,8 @@ while (read_ch == '/' && *read_chptr != '/')
     next_ch();
     if (read_expect_integer(&size, FALSE, FALSE))
       {
-      if (--size < 0 || size >= MaxTextFont)
-        { error_moan(39, MaxTextFont); size = 0; }
+      if (--size < 0 || size >= MaxFontSizes)
+        { error_moan(39, MaxFontSizes); size = 0; }
       }
     break;
 
@@ -1219,8 +1219,8 @@ while (read_ch == '/' && *read_chptr != '/')
             next_ch();
             if (read_expect_integer(sizeptr, FALSE, FALSE))
               {
-              if ((*sizeptr -= 1) < 0 || *sizeptr >= MaxTextFont)
-                { error_moan(39, MaxTextFont); *sizeptr = 0; }
+              if ((*sizeptr -= 1) < 0 || *sizeptr >= MaxFontSizes)
+                { error_moan(39, MaxFontSizes); *sizeptr = 0; }
               }
             break;
 
