@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2016 */
+/* Copyright (c) Philip Hazel, 1991 - 2018 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: June 2016 */
+/* This file last modified: May 2018 */
 
 
 /* This file contains all the major tables used by the program; a few that are
@@ -440,7 +440,7 @@ static int init_accspacing[] = { 0, 5250, 4500, 8000, 4250, 5000 };
 
 
 /* Stemswap level defaults to the third line. This table must be kept in
-stem with stave_bitvec_size. */
+stem with STAVE_BITVEC_SIZE. */
 
 static int init_stemswaplevel[] = {
   P_3L, P_3L, P_3L, P_3L, P_3L, P_3L, P_3L, P_3L,
@@ -483,7 +483,7 @@ static fontsizestr init_fontsizes = {
   10000,     /* vertacc */
 
   /* It doesn't seem possible in ANSI C to parameterize this initialization
-  using MaxTextFont, so we must keep this in step with its value. */
+  using MaxFontSizes, so we must keep this in step with its value. */
 
   { 10000,     /* user font size 1 */
     10000,     /* user font size 2 */
@@ -497,14 +497,13 @@ static fontsizestr init_fontsizes = {
     10000,     /* user font size 10 */
     10000,     /* user font size 11 */
     10000,     /* user font size 12 */
+    11800,     /* tsfont */
+    10000,     /* ulay */
+    10000,     /* olay */
+    10000,     /* fbass */
+    10000      /* init */
   },
 
-  11800,     /* tsfont */
-  10000,     /* ulay */
-  10000,     /* olay */
-  10000,     /* fbass */
-  10000,     /* init */
-
   /* Matrix pointers */
 
   NULL,     /* music */
@@ -522,7 +521,7 @@ static fontsizestr init_fontsizes = {
   NULL,     /* vertacc */
 
   /* It doesn't seem possible in ANSI C to parameterize this initialization
-  using MaxTextFont, so we must keep this in step with its value. */
+  using MaxFontSizes, so we must keep this in step with its value. */
 
   { NULL,     /* user font size 1 */
     NULL,     /* user font size 2 */
@@ -536,17 +535,16 @@ static fontsizestr init_fontsizes = {
     NULL,     /* user font size 10 */
     NULL,     /* user font size 11 */
     NULL,     /* user font size 12 */
-  },
-
-  NULL,     /* tsfont */
-  NULL,     /* ulay */
-  NULL,     /* olay */
-  NULL,     /* fbass */
-  NULL,     /* init */
+    NULL,     /* tsfont */
+    NULL,     /* ulay */
+    NULL,     /* olay */
+    NULL,     /* fbass */
+    NULL      /* init */
+  }
 };
 
 
-/* Default relative stave sizes, must keep in step with stave_bitvec_size */
+/* Default relative stave sizes, must keep in step with STAVE_BITVEC_SIZE */
 
 int init_stavesizes[] =
   {
@@ -559,7 +557,7 @@ int init_stavesizes[] =
   1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
   1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000 };
 
-/* Default relative stave volumes; must keep in step with stave_bitvec_size */
+/* Default relative stave volumes; must keep in step with STAVE_BITVEC_SIZE */
 
 uschar init_play_volume[] =
   { 0, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15,
@@ -567,7 +565,7 @@ uschar init_play_volume[] =
    15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15,
    15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15 };
    
-/* Default midi channels; must keep in step with stave_bitvec_size */ 
+/* Default midi channels; must keep in step with STAVE_BITVEC_SIZE */ 
 
 uschar init_midi_channel[] =
   { 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
@@ -575,7 +573,7 @@ uschar init_midi_channel[] =
     1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
     1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 };
 
-/* Default midi forced pitch; must keep in step with stave_bitvec_size. 
+/* Default midi forced pitch; must keep in step with STAVE_BITVEC_SIZE. 
 Zero means use pitch of note (i.e. don't force). */ 
 
 uschar init_midi_note[] =
@@ -697,6 +695,7 @@ movtstr init_movtstr = {
   310,                /* maxbeamslope1 */ 
   330,                /* maxbeamslope2 */ 
   movt_default,       /* movt_opt */
+  0,                  /* movement number */ 
   11000,              /* overlaydepth */
   120,                /* play_tempo */
   text_box,           /* rehearsalstyle */
@@ -718,7 +717,7 @@ movtstr init_movtstr = {
 
   { 0, 0 },           /* breakbarlines */   /*** must be kept in ***/
   { -1, -1 },         /* staves */          /*** step with ***/
-  { 0, 0 },           /* suspend */         /*** stave_bitvec_size ***/
+  { 0, 0 },           /* suspend */         /*** STAVE_BITVEC_SIZE ***/
   
   { 13, 15, 15, 15, 15, 15, 16, 16, 16, 15, 0, 13, 13, 13, 16, 16 },  /* clefwidths */
   { 0, 0, 0, 0, 0, 0, 2000, 4000 },         /* tailadjusts */ 
@@ -742,7 +741,7 @@ movtstr init_movtstr = {
   FALSE,              /* unfinished */
 
   { 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,   /* playtranspose; must keep in */
-    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,   /* step with stave_bitvec_size */
+    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,   /* step with STAVE_BITVEC_SIZE */
     0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
     0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 }
 };
